@@ -30,6 +30,13 @@ boolean_string = {
     "maximum": 1
 }
 
+non_empty_string = {
+    "type": "string",
+    "minLength": 1,
+    "maxLength": 255,
+    "pattern": "^.*[0-9a-zA-Z]+.*$"
+}
+
 configuration_data_types = {
     "type": "string",
     "minLength": 1,
@@ -42,6 +49,13 @@ configuration_integer_size = {
     "pattern": "[0-9]+"
 }
 
+configuration_positive_integer = {
+    "type": "string",
+    "maxLength": 40,
+    "minLength": 1,
+    "pattern": "^[0-9]+$"
+}
+
 configuration_non_empty_string = {
     "type": "string",
     "minLength": 1,
@@ -51,12 +65,7 @@ configuration_non_empty_string = {
 
 flavorref = {
     'oneOf': [
-        url_ref,
-        {
-            "type": "string",
-            "maxLength": 5,
-            "pattern": "[0-9]+"
-        },
+        non_empty_string,
         {
             "type": "integer"
         }]
@@ -68,18 +77,7 @@ volume_size = {
             "type": "integer",
             "minimum": 0
         },
-        {
-            "type": "string",
-            "minLength": 1,
-            "pattern": "[0-9]+"
-        }]
-}
-
-non_empty_string = {
-    "type": "string",
-    "minLength": 1,
-    "maxLength": 255,
-    "pattern": "^.*[0-9a-zA-Z]+.*$"
+        configuration_positive_integer]
 }
 
 host_string = {
@@ -303,6 +301,8 @@ instance = {
                 "required": [],
                 "properties": {
                     "slave_of": {},
+                    "name": non_empty_string,
+                    "configuration_id": configuration_id,
                 }
             }
         }
@@ -540,8 +540,8 @@ mgmt_configuration = {
                     "name": configuration_non_empty_string,
                     "data_type": configuration_data_types,
                     "restart_required": boolean_string,
-                    "max_size": configuration_integer_size,
-                    "min_size": configuration_integer_size,
+                    "max": configuration_integer_size,
+                    "min": configuration_integer_size,
                 }
             }
         }
@@ -558,8 +558,8 @@ mgmt_configuration = {
                     "name": configuration_non_empty_string,
                     "data_type": configuration_data_types,
                     "restart_required": boolean_string,
-                    "max_size": configuration_integer_size,
-                    "min_size": configuration_integer_size,
+                    "max": configuration_integer_size,
+                    "min": configuration_integer_size,
                 }
             }
         }
