@@ -15,6 +15,8 @@
 
 """Utility methods for working with WSGI servers."""
 
+from __future__ import print_function
+
 import eventlet
 eventlet.patcher.monkey_patch(all=False, socket=True)
 
@@ -25,22 +27,22 @@ import sys
 import time
 
 import eventlet.wsgi
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_serialization import jsonutils
-from oslo_service import service
-from oslo_service import sslutils
+from oslo.config import cfg
 import routes
 import routes.middleware
+#import six
 import webob.dec
 import webob.exc
 from xml.dom import minidom
 from xml.parsers import expat
 
-from trove.common import base_exception
-from trove.common.i18n import _
-from trove.common.utils import req_to_text
-from trove.common import xmlutils
+from trove.openstack.common import exception
+from trove.openstack.common.gettextutils import _
+from trove.openstack.common import jsonutils
+from trove.openstack.common import log as logging
+from trove.openstack.common import service
+from trove.openstack.common import sslutils
+from trove.openstack.common import xmlutils
 
 socket_opts = [
     cfg.IntOpt('backlog',
@@ -69,7 +71,7 @@ class Service(service.Service):
     Provides a Service API for wsgi servers.
 
     This gives us the ability to launch wsgi servers with the
-    Launcher classes in oslo_service.service.py.
+    Launcher classes in service.py.
     """
 
     def __init__(self, application, port,
@@ -99,8 +101,8 @@ class Service(service.Service):
                 sock = eventlet.listen(bind_addr,
                                        backlog=backlog,
                                        family=family)
-                if sslutils.is_enabled(CONF):
-                    sock = sslutils.wrap(CONF, sock)
+                if sslutils.is_enabled():
+                    sock = sslutils.wrap(sock)
 
             except socket.error as err:
                 if err.args[0] != errno.EADDRINUSE:
@@ -157,7 +159,7 @@ class Service(service.Service):
         eventlet.wsgi.server(socket,
                              application,
                              custom_pool=self.tg.pool,
-                             log=logger)
+                             log=logging.WritableLogger(logger))
 
 
 class Middleware(object):
@@ -209,7 +211,7 @@ class Debug(Middleware):
         resp = req.get_response(self.application)
 
         print(("*" * 40) + " RESPONSE HEADERS")
-        for (key, value) in resp.headers.items():
+        for (key, value) in resp.headers.iteritems():
             print(key, "=", value)
         print()
 
@@ -289,7 +291,7 @@ class Router(object):
 
 
 class Request(webob.Request):
-    """Add some OpenStack API-specific logic to the base webob.Request."""
+    """Add some Openstack API-specific logic to the base webob.Request."""
 
     default_request_content_types = ('application/json', 'application/xml')
     default_accept_types = ('application/json', 'application/xml')
@@ -328,11 +330,9 @@ class Request(webob.Request):
                                  self.default_request_content_types)
 
         if content_type not in allowed_content_types:
-            raise base_exception.InvalidContentType(content_type=content_type)
+            raise exception.InvalidContentType(content_type=content_type)
         return content_type
 
-    __str__ = req_to_text
-
 
 class Resource(object):
     """
@@ -369,10 +369,10 @@ class Resource(object):
 
         try:
             action, action_args, accept = self.deserialize_request(request)
-        except base_exception.InvalidContentType:
+        except exception.InvalidContentType:
             msg = _("Unsupported Content-Type")
             return webob.exc.HTTPUnsupportedMediaType(explanation=msg)
-        except base_exception.MalformedRequestBody:
+        except exception.MalformedRequestBody:
             msg = _("Malformed request body")
             return webob.exc.HTTPBadRequest(explanation=msg)
 
@@ -453,7 +453,8 @@ class JSONDictSerializer(DictSerializer):
                 _dtime = obj - datetime.timedelta(microseconds=obj.microsecond)
                 return _dtime.isoformat()
             return obj
-        return jsonutils.dump_as_bytes(data, default=sanitizer)
+#            return six.text_type(obj)
+        return jsonutils.dumps(data, default=sanitizer)
 
 
 class XMLDictSerializer(DictSerializer):
@@ -470,7 +471,7 @@ class XMLDictSerializer(DictSerializer):
 
     def default(self, data):
         # We expect data to contain a single key which is the XML root.
-        root_key = list(data.keys())[0]
+        root_key = data.keys()[0]
         doc = minidom.Document()
         node = self._to_xml_node(doc, self.metadata, root_key, data[root_key])
 
@@ -480,7 +481,7 @@ class XMLDictSerializer(DictSerializer):
         self._add_xmlns(node, has_atom)
         return node.toprettyxml(indent='    ', encoding='UTF-8')
 
-    # NOTE (ameade): the has_atom should be removed after all of the
+    #NOTE (ameade): the has_atom should be removed after all of the
     # xml serializers and view builders have been updated to the current
     # spec that required all responses include the xmlns:atom, the has_atom
     # flag is to prevent current tests from breaking
@@ -500,7 +501,7 @@ class XMLDictSerializer(DictSerializer):
         if xmlns:
             result.setAttribute('xmlns', xmlns)
 
-        # TODO(bcwaldon): accomplish this without a type-check
+        #TODO(bcwaldon): accomplish this without a type-check
         if type(data) is list:
             collections = metadata.get('list_collections', {})
             if nodename in collections:
@@ -519,7 +520,7 @@ class XMLDictSerializer(DictSerializer):
             for item in data:
                 node = self._to_xml_node(doc, metadata, singular, item)
                 result.appendChild(node)
-        # TODO(bcwaldon): accomplish this without a type-check
+        #TODO(bcwaldon): accomplish this without a type-check
         elif type(data) is dict:
             collections = metadata.get('dict_collections', {})
             if nodename in collections:
@@ -604,7 +605,7 @@ class ResponseSerializer(object):
         try:
             return self.body_serializers[content_type]
         except (KeyError, TypeError):
-            raise base_exception.InvalidContentType(content_type=content_type)
+            raise exception.InvalidContentType(content_type=content_type)
 
 
 class RequestHeadersDeserializer(ActionDispatcher):
@@ -658,23 +659,23 @@ class RequestDeserializer(object):
 
     def deserialize_body(self, request, action):
         if not len(request.body) > 0:
-            LOG.debug("Empty body provided in request")
+            LOG.debug(_("Empty body provided in request"))
             return {}
 
         try:
             content_type = request.get_content_type()
-        except base_exception.InvalidContentType:
-            LOG.debug("Unrecognized Content-Type provided in request")
+        except exception.InvalidContentType:
+            LOG.debug(_("Unrecognized Content-Type provided in request"))
             raise
 
         if content_type is None:
-            LOG.debug("No Content-Type provided in request")
+            LOG.debug(_("No Content-Type provided in request"))
             return {}
 
         try:
             deserializer = self.get_body_deserializer(content_type)
-        except base_exception.InvalidContentType:
-            LOG.debug("Unable to deserialize body as provided Content-Type")
+        except exception.InvalidContentType:
+            LOG.debug(_("Unable to deserialize body as provided Content-Type"))
             raise
 
         return deserializer.deserialize(request.body, action)
@@ -683,7 +684,7 @@ class RequestDeserializer(object):
         try:
             return self.body_deserializers[content_type]
         except (KeyError, TypeError):
-            raise base_exception.InvalidContentType(content_type=content_type)
+            raise exception.InvalidContentType(content_type=content_type)
 
     def get_expected_content_type(self, request):
         return request.best_match_content_type(self.supported_content_types)
@@ -725,7 +726,7 @@ class JSONDeserializer(TextDeserializer):
             return jsonutils.loads(datastring)
         except ValueError:
             msg = _("cannot understand JSON")
-            raise base_exception.MalformedRequestBody(reason=msg)
+            raise exception.MalformedRequestBody(reason=msg)
 
     def default(self, datastring):
         return {'body': self._from_json(datastring)}
@@ -749,7 +750,7 @@ class XMLDeserializer(TextDeserializer):
             return {node.nodeName: self._from_xml_node(node, plurals)}
         except expat.ExpatError:
             msg = _("cannot understand XML")
-            raise base_exception.MalformedRequestBody(reason=msg)
+            raise exception.MalformedRequestBody(reason=msg)
 
     def _from_xml_node(self, node, listnames):
         """Convert a minidom node to a simple Python type.
