@@ -1,4 +1,4 @@
-# Copyright 2011 OpenStack Foundation
+# copyright 2011 OpenStack Foundation
 # Copyright 2014 Rackspace Hosting
 # All Rights Reserved.
 #
@@ -15,11 +15,12 @@
 #    under the License.
 """Routines for configuring Trove."""
 
-import trove
-from oslo.config import cfg
-
 import os.path
 
+from oslo.config import cfg
+import trove
+
+
 UNKNOWN_SERVICE_ID = 'unknown-service-id-error'
 
 path_opts = [
@@ -30,19 +31,6 @@ path_opts = [
 ]
 
 common_opts = [
-    cfg.StrOpt('sql_connection',
-               default='sqlite:///trove_test.sqlite',
-               help='SQL Connection.',
-               secret=True),
-    cfg.IntOpt('sql_idle_timeout', default=3600,
-               help="Idle time (in seconds) after which the connection to the "
-                    "database is reestablished. Some databases will drop "
-                    "connections after a specific amount of idle time. "
-                    "Setting sql_idle_timeout to a lower value than this will "
-                    "ensure that a reconnect occurs before the database can "
-                    "drop the connection."),
-    cfg.BoolOpt('sql_query_log', default=False,
-                help='Write all SQL queries to a log.'),
     cfg.StrOpt('bind_host', default='0.0.0.0',
                help='IP address the API server will listen on.'),
     cfg.IntOpt('bind_port', default=8779,
@@ -57,23 +45,33 @@ common_opts = [
                 help='Set the service and instance task statuses to ERROR '
                      'when an instance fails to become active within the '
                      'configured usage_timeout.'),
-    cfg.StrOpt('os_region_name',
+    cfg.StrOpt('os_region_name', default='RegionOne',
                help='Region name of this node. Used when searching catalog.'),
     cfg.StrOpt('nova_compute_url', help='URL without the tenant segment.'),
     cfg.StrOpt('nova_compute_service_type', default='compute',
                help='Service type to use when searching catalog.'),
+    cfg.StrOpt('nova_compute_endpoint_type', default='publicURL',
+               help='Service endpoint type to use when searching catalog.'),
     cfg.StrOpt('neutron_url', help='URL without the tenant segment.'),
     cfg.StrOpt('neutron_service_type', default='network',
                help='Service type to use when searching catalog.'),
+    cfg.StrOpt('neutron_endpoint_type', default='publicURL',
+               help='Service endpoint type to use when searching catalog.'),
     cfg.StrOpt('cinder_url', help='URL without the tenant segment.'),
     cfg.StrOpt('cinder_service_type', default='volumev2',
                help='Service type to use when searching catalog.'),
+    cfg.StrOpt('cinder_endpoint_type', default='publicURL',
+               help='Service endpoint type to use when searching catalog.'),
     cfg.StrOpt('heat_url', help='URL without the tenant segment.'),
     cfg.StrOpt('heat_service_type', default='orchestration',
                help='Service type to use when searching catalog.'),
+    cfg.StrOpt('heat_endpoint_type', default='publicURL',
+               help='Service endpoint type to use when searching catalog.'),
     cfg.StrOpt('swift_url', help='URL ending in AUTH_.'),
     cfg.StrOpt('swift_service_type', default='object-store',
                help='Service type to use when searching catalog.'),
+    cfg.StrOpt('swift_endpoint_type', default='publicURL',
+               help='Service endpoint type to use when searching catalog.'),
     cfg.StrOpt('trove_auth_url', default='http://0.0.0.0:5000/v2.0',
                help='Trove authentication URL.'),
     cfg.StrOpt('host', default='0.0.0.0',
@@ -130,7 +128,8 @@ common_opts = [
     cfg.ListOpt('ignore_users', default=['os_admin', 'root'],
                 help='Users to exclude when listing users.'),
     cfg.ListOpt('ignore_dbs',
-                default=['lost+found', 'mysql', 'information_schema'],
+                default=['lost+found', '#mysql50#lost+found', 'mysql',
+                         'information_schema'],
                 help='Databases to exclude when listing databases.'),
     cfg.IntOpt('agent_call_low_timeout', default=5,
                help="Maximum time (in seconds) to wait for Guest Agent 'quick'"
@@ -149,6 +148,9 @@ common_opts = [
     cfg.IntOpt('agent_heartbeat_time', default=10,
                help='Maximum time (in seconds) for the Guest Agent to reply '
                     'to a heartbeat request.'),
+    cfg.IntOpt('agent_heartbeat_expiry', default=60,
+               help='Time (in seconds) after which a guest is considered '
+                    'unreachable'),
     cfg.IntOpt('num_tries', default=3,
                help='Number of times to check if a volume exists.'),
     cfg.StrOpt('volume_fstype', default='ext3',
@@ -314,7 +316,10 @@ common_opts = [
                          'cassandra': '459a230d-4e97-4344-9067-2a54a310b0ed',
                          'couchbase': 'fa62fe68-74d9-4779-a24e-36f19602c415',
                          'mongodb': 'c8c907af-7375-456f-b929-b637ff9209ee',
-                         'postgresql': 'ac277e0d-4f21-40aa-b347-1ea31e571720'},
+                         'postgresql': 'ac277e0d-4f21-40aa-b347-1ea31e571720',
+                         'couchdb': 'f0a9ab7b-66f7-4352-93d7-071521d44c7c',
+                         'vertica': 'a8d805ae-a3b2-c4fd-gb23-b62cee5201ae',
+                         'db2': 'e040cd37-263d-4869-aaa6-c62aa97523b5'},
                 help='Unique ID to tag notification events.'),
     cfg.StrOpt('nova_proxy_admin_user', default='',
                help="Admin username used to connect to Nova.", secret=True),
@@ -331,9 +336,18 @@ common_opts = [
                     'expression.'),
     cfg.StrOpt('cloudinit_location', default='/etc/trove/cloudinit',
                help='Path to folder with cloudinit scripts.'),
+    cfg.StrOpt('injected_config_location', default='/etc/trove/conf.d',
+               help='Path to folder on the Guest where config files will be '
+                    'injected during instance creation.'),
     cfg.StrOpt('guest_config',
-               default='$pybasedir/etc/trove/trove-guestagent.conf.sample',
-               help='Path to the Guest Agent config file.'),
+               default='/etc/trove/trove-guestagent.conf',
+               help='Path to the Guest Agent config file to be injected '
+                    'during instance creation.'),
+    cfg.StrOpt('guest_info',
+               default='guest_info.conf',
+               help='The guest info filename found in the injected config '
+                    'location.  If a full path is specified then it will '
+                    'be used as the path to the guest info file'),
     cfg.DictOpt('datastore_registry_ext', default=dict(),
                 help='Extension for default datastore managers. '
                      'Allows the use of custom managers for each of '
@@ -372,6 +386,37 @@ common_opts = [
                     'become active.'),
 ]
 
+# Profiling specific option groups
+
+profiler_group = cfg.OptGroup(
+    'profiler', title='Profiler options',
+    help="Oslo option group designed for profiler")
+profiler_opts = [
+    cfg.BoolOpt("enabled", default=False,
+                help="If False fully disable profiling feature."),
+    cfg.BoolOpt("trace_sqlalchemy", default=True,
+                help="If False doesn't trace SQL requests.")
+]
+
+
+database_opts = [
+    cfg.StrOpt('connection',
+               default='sqlite:///trove_test.sqlite',
+               help='SQL Connection.',
+               secret=True,
+               deprecated_name='sql_connection',
+               deprecated_group='DEFAULT'),
+    cfg.IntOpt('idle_timeout',
+               default=3600,
+               deprecated_name='sql_idle_timeout',
+               deprecated_group='DEFAULT'),
+    cfg.BoolOpt('query_log',
+                default=False,
+                deprecated_name='sql_query_log',
+                deprecated_group='DEFAULT'),
+]
+
+
 # Datastore specific option groups
 
 # Mysql
@@ -391,10 +436,10 @@ mysql_opts = [
                help='Default strategy to perform backups.',
                deprecated_name='backup_strategy',
                deprecated_group='DEFAULT'),
-    cfg.StrOpt('replication_strategy', default='MysqlBinlogReplication',
+    cfg.StrOpt('replication_strategy', default='MysqlGTIDReplication',
                help='Default strategy for replication.'),
     cfg.StrOpt('replication_namespace',
-               default='trove.guestagent.strategies.replication.mysql_binlog',
+               default='trove.guestagent.strategies.replication.mysql_gtid',
                help='Namespace to load replication strategies from.'),
     cfg.StrOpt('mount_point', default='/var/lib/mysql',
                help="Filesystem path for mounting "
@@ -448,10 +493,10 @@ percona_opts = [
                help='Default strategy to perform backups.',
                deprecated_name='backup_strategy',
                deprecated_group='DEFAULT'),
-    cfg.StrOpt('replication_strategy', default='MysqlBinlogReplication',
+    cfg.StrOpt('replication_strategy', default='MysqlGTIDReplication',
                help='Default strategy for replication.'),
     cfg.StrOpt('replication_namespace',
-               default='trove.guestagent.strategies.replication.mysql_binlog',
+               default='trove.guestagent.strategies.replication.mysql_gtid',
                help='Namespace to load replication strategies from.'),
     cfg.StrOpt('replication_user', default='slave_user',
                help='Userid for replication slave.'),
@@ -612,12 +657,14 @@ couchbase_opts = [
                 'the root user is immediately returned in the response of '
                 "instance-create as the 'password' field."),
     cfg.StrOpt('backup_namespace',
-               default='trove.guestagent.strategies.backup.couchbase_impl',
+               default='trove.guestagent.strategies.backup.experimental.'
+               'couchbase_impl',
                help='Namespace to load backup strategies from.',
                deprecated_name='backup_namespace',
                deprecated_group='DEFAULT'),
     cfg.StrOpt('restore_namespace',
-               default='trove.guestagent.strategies.restore.couchbase_impl',
+               default='trove.guestagent.strategies.restore.experimental.'
+               'couchbase_impl',
                help='Namespace to load restore strategies from.',
                deprecated_name='restore_namespace',
                deprecated_group='DEFAULT'),
@@ -667,17 +714,17 @@ mongodb_opts = [
     cfg.BoolOpt('cluster_support', default=True,
                 help='Enable clusters to be created and managed.'),
     cfg.StrOpt('api_strategy',
-               default='trove.common.strategies.mongodb.api.'
-                       'MongoDbAPIStrategy',
+               default='trove.common.strategies.cluster.experimental.'
+               'mongodb.api.MongoDbAPIStrategy',
                help='Class that implements datastore-specific API logic.'),
     cfg.StrOpt('taskmanager_strategy',
-               default='trove.common.strategies.mongodb.taskmanager.'
-                       'MongoDbTaskManagerStrategy',
+               default='trove.common.strategies.cluster.experimental.mongodb.'
+               'taskmanager.MongoDbTaskManagerStrategy',
                help='Class that implements datastore-specific task manager '
                     'logic.'),
     cfg.StrOpt('guestagent_strategy',
-               default='trove.common.strategies.mongodb.guestagent.'
-                       'MongoDbGuestAgentStrategy',
+               default='trove.common.strategies.cluster.experimental.'
+               'mongodb.guestagent.MongoDbGuestAgentStrategy',
                help='Class that implements datastore-specific Guest Agent API '
                     'logic.'),
     cfg.StrOpt('backup_namespace', default=None,
@@ -718,10 +765,12 @@ postgresql_opts = [
                 'the root user is immediately returned in the response of '
                 "instance-create as the 'password' field."),
     cfg.StrOpt('backup_namespace',
-               default='trove.guestagent.strategies.backup.postgresql_impl',
+               default='trove.guestagent.strategies.backup.experimental.'
+               'postgresql_impl',
                help='Namespace to load backup strategies from.'),
     cfg.StrOpt('restore_namespace',
-               default='trove.guestagent.strategies.restore.postgresql_impl',
+               default='trove.guestagent.strategies.restore.experimental.'
+               'postgresql_impl',
                help='Namespace to load restore strategies from.'),
     cfg.BoolOpt('volume_support', default=True,
                 help='Whether to provision a Cinder volume for datadir.'),
@@ -730,11 +779,171 @@ postgresql_opts = [
     cfg.ListOpt('ignore_dbs', default=['postgres']),
 ]
 
+# Apache CouchDB
+couchdb_group = cfg.OptGroup(
+    'couchdb', title='CouchDB options',
+    help="Oslo option group designed for CouchDB datastore")
+couchdb_opts = [
+    cfg.ListOpt('tcp_ports',
+                default=["5984"],
+                help='List of TCP ports and/or port ranges to open '
+                     'in the security group (only applicable '
+                     'if trove_security_groups_support is True).'),
+    cfg.ListOpt('udp_ports', default=[],
+                help='List of UDP ports and/or port ranges to open '
+                     'in the security group (only applicable '
+                     'if trove_security_groups_support is True).'),
+    cfg.StrOpt('mount_point', default='/var/lib/couchdb',
+               help="Filesystem path for mounting "
+               "volumes if volume support is enabled."),
+    cfg.BoolOpt('volume_support', default=True,
+                help='Whether to provision a Cinder volume for datadir.'),
+    cfg.StrOpt('device_path', default='/dev/vdb',
+               help='Device path for volume if volume support is enabled.'),
+    cfg.StrOpt('backup_strategy', default=None,
+               help='Default strategy to perform backups.'),
+    cfg.StrOpt('replication_strategy', default=None,
+               help='Default strategy for replication.'),
+    cfg.StrOpt('backup_namespace', default=None,
+               help='Namespace to load backup strategies from.'),
+    cfg.StrOpt('restore_namespace', default=None,
+               help='Namespace to load restore strategies from.'),
+    cfg.DictOpt('backup_incremental_strategy', default={},
+                help='Incremental Backup Runner based on the default '
+                'strategy. For strategies that do not implement an '
+                'incremental, the runner will use the default full backup.'),
+    cfg.BoolOpt('root_on_create', default=False,
+                help='Enable the automatic creation of the root user for the '
+                'service during instance-create. The generated password for '
+                'the root user is immediately returned in the response of '
+                'instance-create as the "password" field.'),
+]
+
+# Vertica
+vertica_group = cfg.OptGroup(
+    'vertica', title='Vertica options',
+    help="Oslo option group designed for Vertica datastore")
+vertica_opts = [
+    cfg.ListOpt('tcp_ports',
+                default=["5433", "5434", "22", "5444", "5450", "4803"],
+                help='List of TCP ports and/or port ranges to open '
+                     'in the security group (only applicable '
+                     'if trove_security_groups_support is True).'),
+    cfg.ListOpt('udp_ports',
+                default=["5433", "4803", "4804", "6453"],
+                help='List of UDP ports and/or port ranges to open '
+                     'in the security group (only applicable '
+                     'if trove_security_groups_support is True).'),
+    cfg.StrOpt('backup_strategy', default=None,
+               help='Default strategy to perform backups.'),
+    cfg.DictOpt('backup_incremental_strategy', default={},
+                help='Incremental Backup Runner based on the default '
+                'strategy. For strategies that do not implement an '
+                'incremental, the runner will use the default full backup.'),
+    cfg.StrOpt('replication_strategy', default=None,
+               help='Default strategy for replication.'),
+    cfg.StrOpt('mount_point', default='/var/lib/vertica',
+               help="Filesystem path for mounting "
+               "volumes if volume support is enabled."),
+    cfg.BoolOpt('volume_support', default=True,
+                help='Whether to provision a Cinder volume for datadir.'),
+    cfg.StrOpt('device_path', default='/dev/vdb',
+               help='Device path for volume if volume support is enabled.'),
+    cfg.StrOpt('backup_namespace', default=None,
+               help='Namespace to load backup strategies from.'),
+    cfg.StrOpt('restore_namespace', default=None,
+               help='Namespace to load restore strategies from.'),
+    cfg.IntOpt('readahead_size', default=2048,
+               help='Size(MB) to be set as readahead_size for data volume'),
+    cfg.BoolOpt('cluster_support', default=True,
+                help='Enable clusters to be created and managed.'),
+    cfg.IntOpt('cluster_member_count', default=3,
+               help='Number of members in Vertica cluster.'),
+    cfg.StrOpt('api_strategy',
+               default='trove.common.strategies.cluster.experimental.vertica.'
+                       'api.VerticaAPIStrategy',
+               help='Class that implements datastore-specific API logic.'),
+    cfg.StrOpt('taskmanager_strategy',
+               default='trove.common.strategies.cluster.experimental.vertica.'
+                       'taskmanager.VerticaTaskManagerStrategy',
+               help='Class that implements datastore-specific task manager '
+                    'logic.'),
+    cfg.StrOpt('guestagent_strategy',
+               default='trove.common.strategies.cluster.experimental.vertica.'
+                       'guestagent.VerticaGuestAgentStrategy',
+               help='Class that implements datastore-specific Guest Agent API '
+                    'logic.'),
+]
+
+# DB2
+db2_group = cfg.OptGroup(
+    'db2', title='DB2 options',
+    help="Oslo option group designed for DB2 datastore")
+db2_opts = [
+    cfg.ListOpt('tcp_ports',
+                default=["50000"],
+                help='List of TCP ports and/or port ranges to open '
+                'in the security group (only applicable '
+                'if trove_security_groups_support is True).'),
+    cfg.ListOpt('udp_ports', default=[],
+                help='List of UDP ports and/or port ranges to open '
+                'in the security group (only applicable '
+                'if trove_security_groups_support is True).'),
+    cfg.StrOpt('mount_point', default="/home/db2inst1/db2inst1",
+               help="Filesystem path for mounting "
+               "volumes if volume support is enabled."),
+    cfg.BoolOpt('volume_support', default=True,
+                help='Whether to provision a Cinder volume for datadir.'),
+    cfg.StrOpt('device_path', default='/dev/vdb',
+               help='Device path for volume if volume support is enabled.'),
+    cfg.StrOpt('backup_strategy', default=None,
+               help='Default strategy to perform backups.'),
+    cfg.StrOpt('replication_strategy', default=None,
+               help='Default strategy for replication.'),
+    cfg.BoolOpt('root_on_create', default=False,
+                help='Enable the automatic creation of the root user for the '
+                'service during instance-create. The generated password for '
+                'the root user is immediately returned in the response of '
+                "instance-create as the 'password' field."),
+    cfg.StrOpt('backup_namespace', default=None,
+               help='Namespace to load backup strategies from.'),
+    cfg.StrOpt('restore_namespace', default=None,
+               help='Namespace to load restore strategies from.'),
+    cfg.DictOpt('backup_incremental_strategy', default={},
+                help='Incremental Backup Runner based on the default '
+                'strategy. For strategies that do not implement an '
+                'incremental, the runner will use the default full backup.'),
+    cfg.ListOpt('ignore_users', default=['PUBLIC', 'DB2INST1']),
+]
+
+# RPC version groups
+upgrade_levels = cfg.OptGroup(
+    'upgrade_levels',
+    title='RPC upgrade levels group for handling versions',
+    help='Contains the support version caps for each RPC API')
+
+rpcapi_cap_opts = [
+    cfg.StrOpt(
+        'taskmanager', default="icehouse",
+        help='Set a version cap for messages sent to taskmanager services'),
+    cfg.StrOpt(
+        'guestagent', default="icehouse",
+        help='Set a version cap for messages sent to guestagent services'),
+    cfg.StrOpt(
+        'conductor', default="icehouse",
+        help='Set a version cap for messages sent to conductor services'),
+]
+
 CONF = cfg.CONF
 
 CONF.register_opts(path_opts)
 CONF.register_opts(common_opts)
 
+CONF.register_group(profiler_group)
+CONF.register_opts(profiler_opts, profiler_group)
+
+CONF.register_opts(database_opts, 'database')
+
 CONF.register_group(mysql_group)
 CONF.register_group(percona_group)
 CONF.register_group(redis_group)
@@ -742,6 +951,9 @@ CONF.register_group(cassandra_group)
 CONF.register_group(couchbase_group)
 CONF.register_group(mongodb_group)
 CONF.register_group(postgresql_group)
+CONF.register_group(couchdb_group)
+CONF.register_group(vertica_group)
+CONF.register_group(db2_group)
 
 CONF.register_opts(mysql_opts, mysql_group)
 CONF.register_opts(percona_opts, percona_group)
@@ -750,6 +962,11 @@ CONF.register_opts(cassandra_opts, cassandra_group)
 CONF.register_opts(couchbase_opts, couchbase_group)
 CONF.register_opts(mongodb_opts, mongodb_group)
 CONF.register_opts(postgresql_opts, postgresql_group)
+CONF.register_opts(couchdb_opts, couchdb_group)
+CONF.register_opts(vertica_opts, vertica_group)
+CONF.register_opts(db2_opts, db2_group)
+
+CONF.register_opts(rpcapi_cap_opts, upgrade_levels)
 
 
 def custom_parser(parsername, parser):
