@@ -17,10 +17,11 @@
 
 import re
 
+from oslo_concurrency import processutils
+
 from trove.openstack.common import log as logging
-from trove.openstack.common import exception as openstack_exception
-from trove.openstack.common import processutils
-from trove.openstack.common.gettextutils import _
+from trove.common import base_exception as openstack_exception
+from trove.common.i18n import _
 
 
 ClientConnectionError = openstack_exception.ClientConnectionError
@@ -130,7 +131,8 @@ class DatastoreVersionInactive(TroveError):
 
 class DatastoreDefaultDatastoreNotFound(TroveError):
 
-    message = _("Please specify datastore.")
+    message = _("Please specify datastore. Default datastore "
+                "cannot be found.")
 
 
 class DatastoreDefaultVersionNotFound(TroveError):
@@ -258,6 +260,11 @@ class ReplicationNotSupported(TroveError):
                 "the '%(datastore)s' datastore.")
 
 
+class ReplicationSlaveAttachError(TroveError):
+
+    message = _("Exception encountered attaching slave to new replica source.")
+
+
 class TaskManagerError(TroveError):
 
     message = _("An error occurred communicating with the task manager: "
@@ -362,7 +369,7 @@ class MalformedSecurityGroupRuleError(TroveError):
 class BackupNotCompleteError(TroveError):
 
     message = _("Unable to create instance because backup %(backup_id)s is "
-                "not completed.")
+                "not completed. Actual state: %(state)s.")
 
 
 class BackupFileNotFound(NotFound):
@@ -380,6 +387,10 @@ class SwiftAuthError(TroveError):
     message = _("Swift account not accessible for tenant %(tenant_id)s.")
 
 
+class SwiftNotFound(TroveError):
+    message = _("Swift is disabled for tenant %(tenant_id)s.")
+
+
 class DatabaseForUserNotInDatabaseListError(TroveError):
     message = _("The request indicates that user %(user)s should have access "
                 "to database %(database)s, but database %(database)s is not "
@@ -439,13 +450,6 @@ class InvalidInstanceState(TroveError):
                 "the instance status is currently: %(status)s.")
 
 
-class RegionAmbiguity(TroveError):
-    """Found more than one matching endpoint in Service Catalog."""
-    message = _("Multiple matches for service_type=%(service_type)s and "
-                "endpoint_region=%(endpoint_region)s. This generally means "
-                "that a region is required and you have not supplied one.")
-
-
 class NoServiceEndpoint(TroveError):
     """Could not find requested endpoint in Service Catalog."""
     message = _("Endpoint not found for service_type=%(service_type)s, "
@@ -480,12 +484,16 @@ class ClusterNotFound(NotFound):
 
 
 class ClusterFlavorsNotEqual(TroveError):
-    message = _("The flavor for each instance in a cluster must be equal.")
+    message = _("The flavor for each instance in a cluster must be the same.")
+
+
+class ClusterVolumeSizeRequired(TroveError):
+    message = _("A volume size is required for each instance in the cluster.")
 
 
 class ClusterVolumeSizesNotEqual(TroveError):
     message = _("The volume size for each instance in a cluster must be "
-                "equal.")
+                "the same.")
 
 
 class ClusterNumInstancesNotSupported(TroveError):
@@ -505,3 +513,9 @@ class TroveOperationAuthError(TroveError):
 class ClusterDatastoreNotSupported(TroveError):
     message = _("Clusters not supported for "
                 "%(datastore)s-%(datastore_version)s.")
+
+
+class BackupTooLarge(TroveError):
+    message = _("Backup is too large for given flavor or volume. "
+                "Backup size: %(backup_size)s GBs. "
+                "Available size: %(disk_size)s GBs.")
