@@ -17,7 +17,7 @@ See http://docs.openstack.org/developer/oslo.i18n/usage.html
 
 """
 
-import oslo_i18n
+import oslo.i18n
 
 
 # NOTE(dhellmann): This reference to o-s-l-o will be replaced by the
@@ -25,7 +25,7 @@ import oslo_i18n
 # repository. It is OK to have more than one translation function
 # using the same domain, since there will still only be one message
 # catalog.
-_translators = oslo_i18n.TranslatorFactory(domain='trove')
+_translators = oslo.i18n.TranslatorFactory(domain='trove')
 
 # The primary translation function using the well-known name "_"
 _ = _translators.primary
