@@ -17,33 +17,33 @@
 import datetime
 import inspect
 import jinja2
-import sys
 import time
 import six.moves.urllib.parse as urlparse
 import uuid
 import os
 import shutil
 
-from eventlet import event
-from eventlet import greenthread
 from eventlet.timeout import Timeout
 from passlib import utils as passlib_utils
 
+from oslo.utils import importutils
+from oslo.utils import timeutils
+from oslo.utils import strutils
+from oslo_concurrency import processutils
+
 from trove.common import cfg
 from trove.common import exception
-from trove.openstack.common import importutils
+from trove.common.i18n import _
 from trove.openstack.common import log as logging
-from trove.openstack.common import processutils
-from trove.openstack.common import timeutils
-from trove.openstack.common import utils as openstack_utils
-from trove.openstack.common.gettextutils import _
+from trove.openstack.common import loopingcall
+
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 import_class = importutils.import_class
 import_object = importutils.import_object
 import_module = importutils.import_module
-bool_from_string = openstack_utils.bool_from_string
+bool_from_string = strutils.bool_from_string
 execute = processutils.execute
 isotime = timeutils.isotime
 
@@ -70,14 +70,14 @@ def create_method_args_string(*args, **kwargs):
 def stringify_keys(dictionary):
     if dictionary is None:
         return None
-    return dict((str(key), value) for key, value in dictionary.iteritems())
+    return {str(key): value for key, value in dictionary.iteritems()}
 
 
 def exclude(key_values, *exclude_keys):
     if key_values is None:
         return None
-    return dict((key, value) for key, value in key_values.iteritems()
-                if key not in exclude_keys)
+    return {key: value for key, value in key_values.iteritems()
+            if key not in exclude_keys}
 
 
 def generate_uuid():
@@ -175,67 +175,6 @@ class MethodInspector(object):
         return "%s %s" % (self._func.__name__, args_str)
 
 
-class LoopingCallDone(Exception):
-    """Exception to break out and stop a LoopingCall.
-
-    The poll-function passed to LoopingCall can raise this exception to
-    break out of the loop normally. This is somewhat analogous to
-    StopIteration.
-
-    An optional return-value can be included as the argument to the exception;
-    this return-value will be returned by LoopingCall.wait()
-
-    """
-
-    def __init__(self, retvalue=True):
-        """:param retvalue: Value that LoopingCall.wait() should return."""
-        super(LoopingCallDone, self).__init__()
-        self.retvalue = retvalue
-
-
-class LoopingCall(object):
-    """Nabbed from nova."""
-    def __init__(self, f=None, *args, **kw):
-        self.args = args
-        self.kw = kw
-        self.f = f
-        self._running = False
-
-    def start(self, interval, now=True):
-        self._running = True
-        done = event.Event()
-
-        def _inner():
-            if not now:
-                greenthread.sleep(interval)
-            try:
-                while self._running:
-                    self.f(*self.args, **self.kw)
-                    if not self._running:
-                        break
-                    greenthread.sleep(interval)
-            except LoopingCallDone as e:
-                self.stop()
-                done.send(e.retvalue)
-            except Exception:
-                LOG.exception(_('In looping call.'))
-                done.send_exception(*sys.exc_info())
-                return
-            else:
-                done.send(True)
-
-        self.done = done
-
-        greenthread.spawn(_inner)
-        return self.done
-
-    def stop(self):
-        self._running = False
-
-    def wait(self):
-        return self.done.wait()
-
-
 def poll_until(retriever, condition=lambda value: value,
                sleep_time=1, time_out=None):
     """Retrieves object until it passes condition, then returns it.
@@ -249,10 +188,14 @@ def poll_until(retriever, condition=lambda value: value,
     def poll_and_check():
         obj = retriever()
         if condition(obj):
-            raise LoopingCallDone(retvalue=obj)
+            raise loopingcall.LoopingCallDone(retvalue=obj)
         if time_out is not None and time.time() - start_time > time_out:
             raise exception.PollTimeOut
-    lc = LoopingCall(f=poll_and_check).start(sleep_time, True)
+
+    lc = loopingcall.FixedIntervalLoopingCall(
+        f=poll_and_check).start(
+            sleep_time, True)
+
     return lc.wait()
 
 
