@@ -13,14 +13,12 @@
 #    under the License.
 
 from sqlalchemy.schema import MetaData
-from sqlalchemy.sql.expression import insert
 from sqlalchemy.sql.expression import select
+from sqlalchemy.sql.expression import insert
 from sqlalchemy.sql.expression import update
-from sqlalchemy import text
-
+from sqlalchemy.sql.expression import delete
 from trove.common import cfg
 from trove.db.sqlalchemy.migrate_repo.schema import Table
-from trove.db.sqlalchemy import utils as db_utils
 
 CONF = cfg.CONF
 LEGACY_IMAGE_ID = "00000000-0000-0000-0000-000000000000"
@@ -54,9 +52,9 @@ def create_legacy_version(datastores_table,
 def find_image(service_name):
     image_table = Table('service_images', meta, autoload=True)
     image = select(
-        columns=[text("id"), text("image_id"), text("service_name")],
+        columns=["id", "image_id", "service_name"],
         from_obj=image_table,
-        whereclause=text("service_name='%s'" % service_name),
+        whereclause="service_name='%s'" % service_name,
         limit=1
     ).execute().fetchone()
 
@@ -67,9 +65,9 @@ def find_image(service_name):
 
 def has_instances_wo_datastore_version(instances_table):
     instance = select(
-        columns=[text("id")],
+        columns=["id"],
         from_obj=instances_table,
-        whereclause=text("datastore_version_id is NULL"),
+        whereclause="datastore_version_id is NULL",
         limit=1
     ).execute().fetchone()
 
@@ -78,9 +76,9 @@ def has_instances_wo_datastore_version(instances_table):
 
 def find_all_instances_wo_datastore_version(instances_table):
     instances = select(
-        columns=[text("id")],
+        columns=["id"],
         from_obj=instances_table,
-        whereclause=text("datastore_version_id is NULL")
+        whereclause="datastore_version_id is NULL"
     ).execute()
 
     return instances
@@ -90,9 +88,6 @@ def upgrade(migrate_engine):
     meta.bind = migrate_engine
 
     instance_table = Table('instances', meta, autoload=True)
-    datastore_versions_table = Table('datastore_versions',
-                                     meta,
-                                     autoload=True)
 
     if has_instances_wo_datastore_version(instance_table):
         instances = find_all_instances_wo_datastore_version(instance_table)
@@ -101,6 +96,9 @@ def upgrade(migrate_engine):
         datastores_table = Table('datastores',
                                  meta,
                                  autoload=True)
+        datastore_versions_table = Table('datastore_versions',
+                                         meta,
+                                         autoload=True)
 
         version_id = create_legacy_version(datastores_table,
                                            datastore_versions_table,
@@ -108,24 +106,38 @@ def upgrade(migrate_engine):
         for instance in instances:
             update(
                 table=instance_table,
-                whereclause=text("id='%s'" % instance.id),
+                whereclause="id='%s'" % instance.id,
                 values=dict(datastore_version_id=version_id)
             ).execute()
 
-    constraint_names = db_utils.get_foreign_key_constraint_names(
-        engine=migrate_engine,
-        table='instances',
-        columns=[text('datastore_version_id')],
-        ref_table='datastore_versions',
-        ref_columns=[text('id')])
-    db_utils.drop_foreign_key_constraints(
-        constraint_names=constraint_names,
-        columns=[instance_table.c.datastore_version_id],
-        ref_columns=[datastore_versions_table.c.id])
-
     instance_table.c.datastore_version_id.alter(nullable=False)
 
-    db_utils.create_foreign_key_constraints(
-        constraint_names=constraint_names,
-        columns=[instance_table.c.datastore_version_id],
-        ref_columns=[datastore_versions_table.c.id])
+
+def downgrade(migrate_engine):
+    meta.bind = migrate_engine
+
+    instance_table = Table('instances', meta, autoload=True)
+
+    instance_table.c.datastore_version_id.alter(nullable=True)
+
+    update(
+        table=instance_table,
+        whereclause="datastore_version_id='%s'" % LEGACY_VERSION_ID,
+        values=dict(datastore_version_id=None)
+    ).execute()
+
+    datastores_table = Table('datastores',
+                             meta,
+                             autoload=True)
+    datastore_versions_table = Table('datastore_versions',
+                                     meta,
+                                     autoload=True)
+
+    delete(
+        table=datastore_versions_table,
+        whereclause="id='%s'" % LEGACY_VERSION_ID
+    ).execute()
+    delete(
+        table=datastores_table,
+        whereclause="id='%s'" % LEGACY_DATASTORE_ID
+    ).execute()
