@@ -18,9 +18,10 @@ from sqlalchemy.schema import Column
 from sqlalchemy.schema import MetaData
 from sqlalchemy.schema import UniqueConstraint
 
-from trove.db.sqlalchemy.migrate_repo.schema import Boolean
 from trove.db.sqlalchemy.migrate_repo.schema import create_tables
+from trove.db.sqlalchemy.migrate_repo.schema import drop_tables
 from trove.db.sqlalchemy.migrate_repo.schema import DateTime
+from trove.db.sqlalchemy.migrate_repo.schema import Boolean
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
 
@@ -52,3 +53,8 @@ def upgrade(migrate_engine):
     meta.bind = migrate_engine
     Table('datastore_versions', meta, autoload=True)
     create_tables([datastore_configuration_parameters])
+
+
+def downgrade(migrate_engine):
+    meta.bind = migrate_engine
+    drop_tables([datastore_configuration_parameters])
