@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from trove.openstack.common import log as logging
 import os
 
 from migrate.versioning import api as versioning_api
@@ -22,7 +23,6 @@ try:
     from migrate.versioning import exceptions as versioning_exceptions
 except ImportError:
     from migrate import exceptions as versioning_exceptions
-from oslo_log import log as logging
 
 from trove.common import exception
 
@@ -64,6 +64,22 @@ def upgrade(options, version=None, repo_path=None):
     return versioning_api.upgrade(sql_connection, repo_path, version)
 
 
+def downgrade(options, version, repo_path=None):
+    """Downgrade the database's current migration level.
+
+    :param options: options dict
+    :param version: version to downgrade to
+    :retval version number
+
+    """
+    db_version(options, repo_path)  # Ensure db is under migration control
+    repo_path = get_migrate_repo_path(repo_path)
+    sql_connection = options['database']['connection']
+    logger.info("Downgrading %(sql_connection)s to version %(version)s" %
+                {'sql_connection': sql_connection, 'version': version})
+    return versioning_api.downgrade(sql_connection, repo_path, version)
+
+
 def version_control(options, repo_path=None):
     """Place a database under migration control.
 
