@@ -14,12 +14,11 @@
 #    under the License.
 
 
-from oslo_log import log as logging
-
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import wsgi
 from trove.extensions.mgmt.host import models
+from trove.openstack.common import log as logging
+from trove.common.i18n import _
 
 LOG = logging.getLogger(__name__)
 
@@ -28,11 +27,9 @@ class HostInstanceController(wsgi.Controller):
     """Controller for all instances on specific hosts."""
 
     def action(self, req, body, tenant_id, host_id):
-        LOG.info("Committing an ACTION against host %(host_id)s for "
-                 "tenant '%(tenant_id)s'\n"
-                 "req : '%(req)s'\n\n", {"req": req, "host_id": host_id,
-                                         "tenant_id": tenant_id})
-
+        LOG.info("req : '%s'\n\n" % req)
+        LOG.info("Committing an ACTION against host %s for tenant '%s'"
+                 % (host_id, tenant_id))
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
         context = req.environ[wsgi.CONTEXT_KEY]
@@ -55,6 +52,6 @@ class HostInstanceController(wsgi.Controller):
             raise exception.BadRequest(_("Invalid request body."))
 
     def _action_update(self, context, host, body):
-        LOG.debug("Updating all instances for host: %s", host.name)
+        LOG.debug("Updating all instances for host: %s" % host.name)
         host.update_all(context)
         return wsgi.Result(None, 202)
