@@ -14,14 +14,15 @@
 import datetime
 
 from trove.common import cfg
+from trove.common import exception
 from trove.common import remote
 from trove.common import utils
 from trove.openstack.common import log as logging
-from trove.openstack.common.notifier import api as notifier
 from trove.instance import models as imodels
 from trove.instance.models import load_instance, InstanceServiceStatus
 from trove.instance import models as instance_models
 from trove.extensions.mysql import models as mysql_models
+from trove import rpc
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -49,22 +50,30 @@ def load_mgmt_instances(context, deleted=None, client=None,
     return instances
 
 
-def load_mgmt_instance(cls, context, id):
+def load_mgmt_instance(cls, context, id, include_deleted):
     try:
-        instance = load_instance(cls, context, id, needs_server=True)
+        instance = load_instance(cls, context, id, needs_server=True,
+                                 include_deleted=include_deleted)
         client = remote.create_nova_client(context)
         try:
             server = client.rdservers.get(instance.server_id)
         except AttributeError:
             server = client.servers.get(instance.server_id)
-        instance.server.host = server.host
-        instance.server.deleted = server.deleted
-        instance.server.deleted_at = server.deleted_at
-        instance.server.local_id = server.local_id
+        if hasattr(server, 'host'):
+            instance.server.host = server.host
+        elif hasattr(server, 'hostId'):
+            instance.server.host = server.hostId
+        if hasattr(server, 'deleted'):
+            instance.server.deleted = server.deleted
+        if hasattr(server, 'deleted_at'):
+            instance.server.deleted_at = server.deleted_at
+        if hasattr(server, 'local_id'):
+            instance.server.local_id = server.local_id
         assert instance.server is not None
     except Exception as e:
         LOG.error(e)
-        instance = load_instance(cls, context, id, needs_server=False)
+        instance = load_instance(cls, context, id, needs_server=False,
+                                 include_deleted=include_deleted)
     return instance
 
 
@@ -88,8 +97,8 @@ class SimpleMgmtInstance(imodels.BaseInstance):
         return self.db_info.deleted_at
 
     @classmethod
-    def load(cls, context, id):
-        return load_mgmt_instance(cls, context, id)
+    def load(cls, context, id, include_deleted=False):
+        return load_mgmt_instance(cls, context, id, include_deleted)
 
     @property
     def task_description(self):
@@ -105,8 +114,8 @@ class DetailedMgmtInstance(SimpleMgmtInstance):
         self.root_history = None
 
     @classmethod
-    def load(cls, context, id):
-        instance = load_mgmt_instance(cls, context, id)
+    def load(cls, context, id, include_deleted=False):
+        instance = load_mgmt_instance(cls, context, id, include_deleted)
         client = remote.create_cinder_client(context)
         try:
             instance.volume = client.volumes.get(instance.volume_id)
@@ -129,6 +138,9 @@ class MgmtInstance(imodels.Instance):
     def get_hwinfo(self):
         return self.get_guest().get_hwinfo()
 
+    def rpc_ping(self):
+        return self.get_guest().rpc_ping()
+
 
 class MgmtInstances(imodels.Instances):
     @staticmethod
@@ -160,15 +172,12 @@ def _load_servers(instances, find_server):
 
 
 def publish_exist_events(transformer, admin_context):
+    notifier = rpc.get_notifier("taskmanager")
     notifications = transformer()
     # clear out admin_context.auth_token so it does not get logged
     admin_context.auth_token = None
     for notification in notifications:
-        notifier.notify(admin_context,
-                        CONF.host,
-                        "trove.instance.exists",
-                        'INFO',
-                        notification)
+        notifier.info(admin_context, "trove.instance.exists", notification)
 
 
 class NotificationTransformer(object):
@@ -219,8 +228,18 @@ class NotificationTransformer(object):
         messages = []
         db_infos = instance_models.DBInstance.find_all(deleted=False)
         for db_info in db_infos:
-            service_status = InstanceServiceStatus.find_by(
-                instance_id=db_info.id)
+            try:
+                service_status = InstanceServiceStatus.find_by(
+                    instance_id=db_info.id)
+            except exception.ModelNotFoundError:
+                # There is a small window of opportunity during when the db
+                # resource for an instance exists, but no InstanceServiceStatus
+                # for it has yet been created. We skip sending the notification
+                # message for all such instances. These instance are too new
+                # and will get picked up the next round of notifications.
+                LOG.debug("InstanceServiceStatus not found for %s. "
+                          "Will wait to send notification." % db_info.id)
+                continue
             instance = SimpleMgmtInstance(None, db_info, None, service_status)
             message = self.transform_instance(instance, audit_start, audit_end)
             messages.append(message)
