@@ -28,7 +28,7 @@ from trove.extensions.mgmt.instances.views import HwInfoView
 from trove.extensions.mysql import models as mysql_models
 from trove.instance.service import InstanceController
 from trove.openstack.common import log as logging
-from trove.openstack.common.gettextutils import _
+from trove.common.i18n import _
 import trove.common.apischema as apischema
 
 
@@ -74,9 +74,11 @@ class MgmtInstanceController(InstanceController):
         LOG.info(_("req : '%s'\n\n") % req)
         LOG.info(_("Showing a database instance for tenant '%s'") % tenant_id)
         LOG.info(_("id : '%s'\n\n") % id)
-
         context = req.environ[wsgi.CONTEXT_KEY]
-        server = models.DetailedMgmtInstance.load(context, id)
+        deleted_q = req.GET.get('deleted', '').lower()
+        include_deleted = deleted_q == 'true'
+        server = models.DetailedMgmtInstance.load(context, id,
+                                                  include_deleted)
         root_history = mysql_models.RootHistory.load(context=context,
                                                      instance_id=id)
         return wsgi.Result(
@@ -189,3 +191,14 @@ class MgmtInstanceController(InstanceController):
 
         diagnostics = instance.get_diagnostics()
         return wsgi.Result(DiagnosticsView(id, diagnostics).data(), 200)
+
+    @admin_context
+    def rpc_ping(self, req, tenant_id, id):
+        """Checks if instance is reachable via rpc."""
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("id : '%s'\n\n") % id)
+        context = req.environ[wsgi.CONTEXT_KEY]
+        instance = models.MgmtInstance.load(context=context, id=id)
+
+        instance.rpc_ping()
+        return wsgi.Result(None, 204)
