@@ -14,23 +14,18 @@
 #    under the License.
 
 import itertools
-
-from oslo_log import log as logging
-
 from trove.common import cfg
-from trove.common.i18n import _
-from trove.common.notification import EndNotification
 from trove.guestagent.datastore.experimental.postgresql import pgutil
+from trove.openstack.common import log as logging
+from trove.common.i18n import _
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
+IGNORE_DBS_LIST = CONF.get(CONF.datastore_manager).ignore_dbs
 
 
 class PgSqlDatabase(object):
 
-    def __init__(self, *args, **kwargs):
-        super(PgSqlDatabase, self).__init__(*args, **kwargs)
-
     def create_database(self, context, databases):
         """Create the list of specified databases.
 
@@ -42,24 +37,23 @@ class PgSqlDatabase(object):
         Encoding and collation values are validated in
         trove.guestagent.db.models.
         """
-        with EndNotification(context):
-            for database in databases:
-                encoding = database.get('_character_set')
-                collate = database.get('_collate')
-                LOG.info(
-                    _("{guest_id}: Creating database {name}.").format(
-                        guest_id=CONF.guest_id,
-                        name=database['_name'],
-                    )
-                )
-                pgutil.psql(
-                    pgutil.DatabaseQuery.create(
-                        name=database['_name'],
-                        encoding=encoding,
-                        collation=collate,
-                    ),
-                    timeout=30,
+        for database in databases:
+            encoding = database.get('_character_set')
+            collate = database.get('_collate')
+            LOG.info(
+                _("{guest_id}: Creating database {name}.").format(
+                    guest_id=CONF.guest_id,
+                    name=database['_name'],
                 )
+            )
+            pgutil.psql(
+                pgutil.DatabaseQuery.create(
+                    name=database['_name'],
+                    encoding=encoding,
+                    collation=collate,
+                ),
+                timeout=30,
+            )
 
     def delete_database(self, context, database):
         """Delete the specified database.
@@ -68,17 +62,16 @@ class PgSqlDatabase(object):
 
             {"_name": ""}
         """
-        with EndNotification(context):
-            LOG.info(
-                _("{guest_id}: Dropping database {name}.").format(
-                    guest_id=CONF.guest_id,
-                    name=database['_name'],
-                )
-            )
-            pgutil.psql(
-                pgutil.DatabaseQuery.drop(name=database['_name']),
-                timeout=30,
+        LOG.info(
+            _("{guest_id}: Dropping database {name}.").format(
+                guest_id=CONF.guest_id,
+                name=database['_name'],
             )
+        )
+        pgutil.psql(
+            pgutil.DatabaseQuery.drop(name=database['_name']),
+            timeout=30,
+        )
 
     def list_databases(
             self,
@@ -94,8 +87,7 @@ class PgSqlDatabase(object):
             [{"_name": "", "_character_set": "", "_collate": ""}, ...]
         """
         results = pgutil.query(
-            pgutil.DatabaseQuery.list(ignore=cfg.get_ignored_dbs(
-                manager='postgresql')),
+            pgutil.DatabaseQuery.list(ignore=IGNORE_DBS_LIST),
             timeout=30,
         )
         # Convert results to dictionaries.
