@@ -16,14 +16,13 @@
 
 import json
 
-from oslo_log import log as logging
-
 from trove.common import exception
 from trove.common import utils
-from trove.guestagent.common import operating_system
 from trove.guestagent.datastore.experimental.couchbase import service
 from trove.guestagent.datastore.experimental.couchbase import system
 from trove.guestagent.strategies.backup import base
+from trove.common.i18n import _
+from trove.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -64,8 +63,7 @@ class CbBackup(base.BackupRunner):
                                    system.COUCHBASE_REST_API,
                                    system.COUCHBASE_DUMP_DIR,
                                    '-u', 'root', '-p', password,
-                                   timeout=600, run_as_root=True,
-                                   root_helper='sudo')
+                                   timeout=600)
 
     def _run_pre_backup(self):
         try:
@@ -87,22 +85,25 @@ class CbBackup(base.BackupRunner):
                     if not all_memcached:
                         self._backup(pw)
                     else:
-                        LOG.info("All buckets are memcached.  "
-                                 "Skipping backup.")
-            operating_system.move(OUTFILE, system.COUCHBASE_DUMP_DIR)
+                        LOG.info(_("All buckets are memcached.  "
+                                   "Skipping backup."))
+            utils.execute_with_timeout('mv', OUTFILE,
+                                       system.COUCHBASE_DUMP_DIR)
             if pw != "password":
                 # Not default password, backup generated root password
-                operating_system.copy(system.pwd_file,
-                                      system.COUCHBASE_DUMP_DIR,
-                                      preserve=True, as_root=True)
-        except exception.ProcessExecutionError:
-            LOG.exception("Error during pre-backup phase.")
-            raise
+                utils.execute_with_timeout('cp', '-p',
+                                           system.pwd_file,
+                                           system.COUCHBASE_DUMP_DIR,
+                                           run_as_root=True,
+                                           root_helper='sudo')
+        except exception.ProcessExecutionError as p:
+            LOG.error(p)
+            raise p
 
     def _run_post_backup(self):
         try:
             for cmd in self.post_backup_commands:
                 utils.execute_with_timeout(*cmd)
-        except exception.ProcessExecutionError:
-            LOG.exception("Error during post-backup phase.")
-            raise
+        except exception.ProcessExecutionError as p:
+            LOG.error(p)
+            raise p
