@@ -14,9 +14,8 @@
 #    under the License.
 #
 
-from oslo_log import log as logging
-
 from trove.guestagent.strategy import Strategy
+from trove.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
