@@ -41,7 +41,7 @@ class Replication(Strategy):
         """Capture snapshot of master db."""
 
     @abc.abstractmethod
-    def enable_as_master(self, service, snapshot_info):
+    def enable_as_master(self, service, master_config):
         """Configure underlying database to act as master for replication."""
 
     @abc.abstractmethod
@@ -49,7 +49,7 @@ class Replication(Strategy):
         """Configure underlying database as a slave of the given master."""
 
     @abc.abstractmethod
-    def detach_slave(self, service):
+    def detach_slave(self, service, for_failover):
         """Turn off replication on a slave site."""
 
     @abc.abstractmethod
