@@ -17,6 +17,7 @@
 import glob
 import os
 import pexpect
+import re
 import tempfile
 
 from trove.guestagent.strategies.restore import base
@@ -24,7 +25,7 @@ from trove.openstack.common import log as logging
 from trove.common import exception
 from trove.common import utils
 import trove.guestagent.datastore.mysql.service as dbaas
-from trove.openstack.common.gettextutils import _  # noqa
+from trove.common.i18n import _  # noqa
 
 LOG = logging.getLogger(__name__)
 
@@ -33,22 +34,35 @@ class MySQLRestoreMixin(object):
     """Common utils for restoring MySQL databases."""
     RESET_ROOT_RETRY_TIMEOUT = 100
     RESET_ROOT_SLEEP_INTERVAL = 10
-    RESET_ROOT_MYSQL_COMMAND = ("SET PASSWORD FOR"
-                                "'root'@'localhost'=PASSWORD('');")
+
+    # Reset the root password in a single transaction with 'FLUSH PRIVILEGES'
+    # to ensure we never leave database wide open without 'grant tables'.
+    RESET_ROOT_MYSQL_COMMANDS = ("START TRANSACTION;",
+                                 "UPDATE `mysql`.`user` SET"
+                                 " `password`=PASSWORD('')"
+                                 " WHERE `user`='root';",
+                                 "FLUSH PRIVILEGES;",
+                                 "COMMIT;")
+    # This is a suffix MySQL appends to the file name given in
+    # the '--log-error' startup parameter.
+    _ERROR_LOG_SUFFIX = '.err'
+    _ERROR_MESSAGE_PATTERN = re.compile("^ERROR:\s+.+$")
 
     def mysql_is_running(self):
-        if base.exec_with_root_helper("/usr/bin/mysqladmin", "ping"):
+        try:
+            utils.execute_with_timeout("/usr/bin/mysqladmin", "ping")
             LOG.debug("MySQL is up and running.")
             return True
-        else:
+        except exception.ProcessExecutionError:
             LOG.debug("MySQL is not running.")
             return False
 
     def mysql_is_not_running(self):
-        if base.exec_with_root_helper("/usr/bin/pgrep", "mysqld"):
+        try:
+            utils.execute_with_timeout("/usr/bin/pgrep", "mysqld")
             LOG.info("MySQL is still running.")
             return False
-        else:
+        except exception.ProcessExecutionError:
             LOG.debug("MySQL is not running.")
             return True
 
@@ -60,9 +74,14 @@ class MySQLRestoreMixin(object):
         except exception.PollTimeOut:
             raise exc
 
-    def _spawn_with_init_file(self, temp_file):
-        child = pexpect.spawn("sudo mysqld_safe --init-file=%s" %
-                              temp_file.name)
+    def _start_mysqld_safe_with_init_file(self, init_file, err_log_file):
+        child = pexpect.spawn("sudo mysqld_safe"
+                              " --skip-grant-tables"
+                              " --skip-networking"
+                              " --init-file='%s'"
+                              " --log-error='%s'" %
+                              (init_file.name, err_log_file.name)
+                              )
         try:
             i = child.expect(['Starting mysqld daemon'])
             if i == 0:
@@ -72,28 +91,93 @@ class MySQLRestoreMixin(object):
         finally:
             # There is a race condition here where we kill mysqld before
             # the init file been executed. We need to ensure mysqld is up.
+            #
+            # mysqld_safe will start even if init-file statement(s) fail.
+            # We therefore also check for errors in the log file.
             self.poll_until_then_raise(
                 self.mysql_is_running,
-                base.RestoreError("Reset root password failed: "
-                                  "mysqld did not start!"))
+                base.RestoreError("Reset root password failed:"
+                                  " mysqld did not start!"))
+            first_err_message = self._find_first_error_message(err_log_file)
+            if first_err_message:
+                raise base.RestoreError("Reset root password failed: %s"
+                                        % first_err_message)
+
             LOG.info(_("Root password reset successfully."))
             LOG.debug("Cleaning up the temp mysqld process.")
-            utils.execute_with_timeout("mysqladmin", "-uroot",
-                                       "--protocol=tcp", "shutdown")
-            utils.execute_with_timeout("killall", "mysqld_safe",
-                                       root_helper="sudo", run_as_root=True)
-            self.poll_until_then_raise(
-                self.mysql_is_not_running,
-                base.RestoreError("Reset root password failed: "
-                                  "mysqld did not stop!"))
+            utils.execute_with_timeout("mysqladmin", "-uroot", "shutdown")
+            LOG.debug("Polling for shutdown to complete.")
+            try:
+                utils.poll_until(self.mysql_is_not_running,
+                                 sleep_time=self.RESET_ROOT_SLEEP_INTERVAL,
+                                 time_out=self.RESET_ROOT_RETRY_TIMEOUT)
+                LOG.debug("Database successfully shutdown")
+            except exception.PollTimeOut:
+                LOG.debug("Timeout shutting down database "
+                          "- performing killall on mysqld_safe.")
+                utils.execute_with_timeout("killall", "mysqld_safe",
+                                           root_helper="sudo",
+                                           run_as_root=True)
+                self.poll_until_then_raise(
+                    self.mysql_is_not_running,
+                    base.RestoreError("Reset root password failed: "
+                                      "mysqld did not stop!"))
 
     def reset_root_password(self):
-        #Create temp file with reset root password
-        with tempfile.NamedTemporaryFile() as fp:
-            fp.write(self.RESET_ROOT_MYSQL_COMMAND)
-            fp.flush()
-            utils.execute_with_timeout("sudo", "chmod", "a+r", fp.name)
-            self._spawn_with_init_file(fp)
+        with tempfile.NamedTemporaryFile() as init_file:
+            utils.execute_with_timeout("sudo", "chmod", "a+r", init_file.name)
+            self._writelines_one_per_line(init_file,
+                                          self.RESET_ROOT_MYSQL_COMMANDS)
+            # Do not attempt to delete the file as the 'trove' user.
+            # The process writing into it may have assumed its ownership.
+            # Only owners can delete temporary
+            # files (restricted deletion).
+            err_log_file = tempfile.NamedTemporaryFile(
+                suffix=self._ERROR_LOG_SUFFIX,
+                delete=False)
+            try:
+                self._start_mysqld_safe_with_init_file(init_file, err_log_file)
+            finally:
+                err_log_file.close()
+                MySQLRestoreMixin._delete_file(err_log_file.name)
+
+    def _writelines_one_per_line(self, fp, lines):
+        fp.write(os.linesep.join(lines))
+        fp.flush()
+
+    def _find_first_error_message(self, fp):
+        if MySQLRestoreMixin._is_non_zero_file(fp):
+                return MySQLRestoreMixin._find_first_pattern_match(
+                    fp,
+                    self._ERROR_MESSAGE_PATTERN
+                )
+        return None
+
+    @classmethod
+    def _delete_file(self, file_path):
+        """Force-remove a given file as root.
+        Do not raise an exception on failure.
+        """
+
+        if os.path.isfile(file_path):
+            try:
+                utils.execute_with_timeout("rm", "-f", file_path,
+                                           run_as_root=True,
+                                           root_helper="sudo")
+            except Exception:
+                LOG.exception("Could not remove file: '%s'" % file_path)
+
+    @classmethod
+    def _is_non_zero_file(self, fp):
+        file_path = fp.name
+        return os.path.isfile(file_path) and (os.path.getsize(file_path) > 0)
+
+    @classmethod
+    def _find_first_pattern_match(self, fp, pattern):
+        for line in fp:
+            if pattern.match(line):
+                return line
+        return None
 
 
 class MySQLDump(base.RestoreRunner, MySQLRestoreMixin):
@@ -211,7 +295,7 @@ class InnoBackupExIncremental(InnoBackupEx):
             self._incremental_restore(parent_location, parent_checksum)
             # for *this* backup set the incremental_dir
             # just use the checksum for the incremental path as it is
-            # sufficently unique /var/lib/mysql/<checksum>
+            # sufficiently unique /var/lib/mysql/<checksum>
             incremental_dir = os.path.join(self.restore_location, checksum)
             utils.execute("mkdir", "-p", incremental_dir,
                           root_helper="sudo",
