@@ -13,11 +13,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from __builtin__ import setattr
 
 """Model classes that form the core of instances functionality."""
-
 import re
 from datetime import datetime
+from datetime import timedelta
 from novaclient import exceptions as nova_exceptions
 from oslo.config.cfg import NoSuchOptError
 from trove.common import cfg
@@ -40,8 +41,9 @@ from trove.instance.tasks import InstanceTask
 from trove.instance.tasks import InstanceTasks
 from trove.taskmanager import api as task_api
 from trove.openstack.common import log as logging
-from trove.openstack.common.gettextutils import _
+from trove.common import i18n as i18n
 
+(_, _LE, _LI, _LW) = (i18n._, i18n._LE, i18n._LI, i18n._LW)
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
@@ -65,13 +67,13 @@ def load_server(context, instance_id, server_id):
     :type context: trove.common.context.TroveContext
     :type instance_id: unicode
     :type server_id: unicode
-    :rtype: novaclient.v1_1.servers.Server
+    :rtype: novaclient.v2.servers.Server
     """
     client = create_nova_client(context)
     try:
         server = client.servers.get(server_id)
     except nova_exceptions.NotFound:
-        LOG.error(_("Could not find nova server_id(%s).") % server_id)
+        LOG.error(_LE("Could not find nova server_id(%s)."), server_id)
         raise exception.ComputeInstanceNotFound(instance_id=instance_id,
                                                 server_id=server_id)
     except nova_exceptions.ClientException as e:
@@ -90,6 +92,8 @@ class InstanceStatus(object):
     SHUTDOWN = "SHUTDOWN"
     ERROR = "ERROR"
     RESTART_REQUIRED = "RESTART_REQUIRED"
+    PROMOTE = "PROMOTE"
+    EJECT = "EJECT"
 
 
 def validate_volume_size(size):
@@ -120,7 +124,7 @@ def load_simple_instance_server_status(context, db_info):
 
 
 # Invalid states to contact the agent
-AGENT_INVALID_STATUSES = ["BUILD", "REBOOT", "RESIZE"]
+AGENT_INVALID_STATUSES = ["BUILD", "REBOOT", "RESIZE", "PROMOTE", "EJECT"]
 
 
 class SimpleInstance(object):
@@ -286,6 +290,10 @@ class SimpleInstance(object):
             return InstanceStatus.RESIZE
         if 'RESTART_REQUIRED' == action:
             return InstanceStatus.RESTART_REQUIRED
+        if InstanceTasks.PROMOTING.action == action:
+            return InstanceStatus.PROMOTE
+        if InstanceTasks.EJECTING.action == action:
+            return InstanceStatus.EJECT
 
         ### Check for server status.
         if self.db_info.server_status in ["BUILD", "ERROR", "REBOOT",
@@ -306,8 +314,8 @@ class SimpleInstance(object):
             if self.db_info.server_status in ["ACTIVE", "SHUTDOWN", "DELETED"]:
                 return InstanceStatus.SHUTDOWN
             else:
-                LOG.error(_("While shutting down instance (%(instance)s): "
-                            "server had status (%(status)s).") %
+                LOG.error(_LE("While shutting down instance (%(instance)s): "
+                              "server had status (%(status)s)."),
                           {'instance': self.id,
                            'status': self.db_info.server_status})
                 return InstanceStatus.ERROR
@@ -408,7 +416,7 @@ class DetailInstance(SimpleInstance):
         self._volume_total = value
 
 
-def get_db_info(context, id, cluster_id=None):
+def get_db_info(context, id, cluster_id=None, include_deleted=False):
     """
     Retrieves an instance of the managed datastore from the persisted
     storage based on the ID and Context
@@ -425,12 +433,14 @@ def get_db_info(context, id, cluster_id=None):
         raise TypeError("Argument context not defined.")
     elif id is None:
         raise TypeError("Argument id not defined.")
+
+    args = {'id': id}
+    if cluster_id is not None:
+        args['cluster_id'] = cluster_id
+    if not include_deleted:
+        args['deleted'] = False
     try:
-        if cluster_id is not None:
-            db_info = DBInstance.find_by(context=context, id=id,
-                                         cluster_id=cluster_id, deleted=False)
-        else:
-            db_info = DBInstance.find_by(context=context, id=id, deleted=False)
+        db_info = DBInstance.find_by(context=context, **args)
     except exception.NotFound:
         raise exception.NotFound(uuid=id)
     return db_info
@@ -443,12 +453,13 @@ def load_any_instance(context, id, load_server=True):
         return load_instance(BuiltInstance, context, id,
                              needs_server=load_server)
     except exception.UnprocessableEntity:
-        LOG.warn(_("Could not load instance %s.") % id)
+        LOG.warn(_LW("Could not load instance %s."), id)
         return load_instance(FreshInstance, context, id, needs_server=False)
 
 
-def load_instance(cls, context, id, needs_server=False):
-    db_info = get_db_info(context, id)
+def load_instance(cls, context, id, needs_server=False,
+                  include_deleted=False):
+    db_info = get_db_info(context, id, include_deleted=include_deleted)
     if not needs_server:
         # TODO(tim.simpson): When we have notifications this won't be
         # necessary and instead we'll just use the server_status field from
@@ -463,14 +474,14 @@ def load_instance(cls, context, id, needs_server=False):
             db_info.server_status = server.status
             db_info.addresses = server.addresses
         except exception.ComputeInstanceNotFound:
-            LOG.error(_("Could not load compute instance %s.") %
+            LOG.error(_LE("Could not load compute instance %s."),
                       db_info.compute_instance_id)
             raise exception.UnprocessableEntity("Instance %s is not ready." %
                                                 id)
 
     service_status = InstanceServiceStatus.find_by(instance_id=id)
-    LOG.debug("Instance %(instance_id)s service status is %(service_status)s."
-              % {'instance_id': id, 'service_status': service_status.status})
+    LOG.debug("Instance %(instance_id)s service status is %(service_status)s.",
+              {'instance_id': id, 'service_status': service_status.status})
     return cls(context, db_info, server, service_status)
 
 
@@ -478,8 +489,8 @@ def load_instance_with_guest(cls, context, id, cluster_id=None):
     db_info = get_db_info(context, id, cluster_id)
     load_simple_instance_server_status(context, db_info)
     service_status = InstanceServiceStatus.find_by(instance_id=id)
-    LOG.debug("Instance %(instance_id)s service status is %(service_status)s."
-              % {'instance_id': id, 'service_status': service_status.status})
+    LOG.debug("Instance %(instance_id)s service status is %(service_status)s.",
+              {'instance_id': id, 'service_status': service_status.status})
     instance = cls(context, db_info, service_status)
     load_guest_info(instance, context, id)
     return instance
@@ -528,7 +539,7 @@ class BaseInstance(SimpleInstance):
         instance at it exists in the db
         :type context: trove.common.context.TroveContext
         :type db_info: trove.instance.models.DBInstance
-        :type server: novaclient.v1_1.servers.Server
+        :type server: novaclient.v2.servers.Server
         :typdatastore_statusus: trove.instance.models.InstanceServiceStatus
         """
         super(BaseInstance, self).__init__(context, db_info, datastore_status)
@@ -545,7 +556,7 @@ class BaseInstance(SimpleInstance):
             if self.is_building:
                 raise exception.UnprocessableEntity("Instance %s is not ready."
                                                     % self.id)
-            LOG.debug("Deleting instance with compute id = %s." %
+            LOG.debug("Deleting instance with compute id = %s.",
                       self.db_info.compute_instance_id)
 
             from trove.cluster.models import is_cluster_deleting
@@ -576,13 +587,7 @@ class BaseInstance(SimpleInstance):
     def delete_async(self):
         deleted_at = datetime.utcnow()
         self._delete_resources(deleted_at)
-        LOG.debug("Setting instance %s to be deleted." % self.id)
-        # Delete guest queue.
-        try:
-            guest = self.get_guest()
-            guest.delete_queue()
-        except Exception as ex:
-            LOG.warn(ex)
+        LOG.debug("Setting instance %s to be deleted.", self.id)
         self.update_db(deleted=True, deleted_at=deleted_at,
                        task_status=InstanceTasks.NONE)
         self.set_servicestatus_deleted()
@@ -621,7 +626,8 @@ class BaseInstance(SimpleInstance):
         return self._volume_client
 
     def reset_task_status(self):
-        LOG.info(_("Resetting task status to NONE on instance %s.") % self.id)
+        LOG.info(_LI("Resetting task status to NONE on instance %s."),
+                 self.id)
         self.update_db(task_status=InstanceTasks.NONE)
 
 
@@ -652,15 +658,15 @@ class Instance(BuiltInstance):
             return root_on_create
         except NoSuchOptError:
             LOG.debug("root_on_create not configured for %s,"
-                      " hence defaulting the value to False."
-                      % datastore_manager)
+                      " hence defaulting the value to False.",
+                      datastore_manager)
             return False
 
     @classmethod
     def create(cls, context, name, flavor_id, image_id, databases, users,
                datastore, datastore_version, volume_size, backup_id,
                availability_zone=None, nics=None, configuration_id=None,
-               slave_of_id=None, cluster_config=None):
+               slave_of_id=None, cluster_config=None, replica_count=None):
 
         datastore_cfg = CONF.get(datastore_version.manager)
         client = create_nova_client(context)
@@ -674,18 +680,27 @@ class Instance(BuiltInstance):
         if volume_support:
             validate_volume_size(volume_size)
             deltas['volumes'] = volume_size
+            # Instance volume should have enough space for the backup
+            # Backup, and volume sizes are in GBs
+            target_size = volume_size
         else:
+            target_size = flavor.disk  # local_storage
             if volume_size is not None:
                 raise exception.VolumeNotSupported()
-            ephemeral_support = datastore_cfg.device_path
-            if ephemeral_support:
+            if datastore_cfg.device_path:
                 if flavor.ephemeral == 0:
                     raise exception.LocalStorageNotSpecified(flavor=flavor_id)
+                target_size = flavor.ephemeral  # ephemeral_Storage
 
-        if backup_id is not None:
+        if backup_id:
             backup_info = Backup.get_by_id(context, backup_id)
-            if backup_info.is_running:
-                raise exception.BackupNotCompleteError(backup_id=backup_id)
+            if not backup_info.is_done_successfuly:
+                raise exception.BackupNotCompleteError(
+                    backup_id=backup_id, state=backup_info.state)
+
+            if backup_info.size > target_size:
+                raise exception.BackupTooLarge(
+                    backup_size=backup_info.size, disk_size=target_size)
 
             if not backup_info.check_swift_object_exist(
                     context,
@@ -704,6 +719,40 @@ class Instance(BuiltInstance):
             if not replication_support:
                 raise exception.ReplicationNotSupported(
                     datastore=datastore.name)
+            try:
+                # looking for replica source
+                replica_source = DBInstance.find_by(
+                    context,
+                    id=slave_of_id,
+                    deleted=False)
+                if replica_source.slave_of_id:
+                    raise exception.Forbidden(
+                        _("Cannot create a replica of a replica %(id)s.")
+                        % {'id': slave_of_id})
+                # load the replica source status to check if
+                # source is available
+                load_simple_instance_server_status(
+                    context,
+                    replica_source)
+                replica_source_instance = Instance(
+                    context, replica_source,
+                    None,
+                    InstanceServiceStatus.find_by(
+                        context,
+                        instance_id=slave_of_id))
+                replica_source_instance.validate_can_perform_action()
+            except exception.ModelNotFoundError:
+                LOG.exception(
+                    _("Cannot create a replica of %(id)s "
+                      "as that instance could not be found.")
+                    % {'id': slave_of_id})
+                raise exception.NotFound(uuid=slave_of_id)
+        elif replica_count and replica_count != 1:
+            raise exception.Forbidden(_(
+                "Replica count only valid when creating replicas. Cannot "
+                "create %(count)d instances.") % {'count': replica_count})
+        multi_replica = slave_of_id and replica_count and replica_count > 1
+        instance_count = replica_count if multi_replica else 1
 
         if not nics:
             nics = []
@@ -720,50 +769,68 @@ class Instance(BuiltInstance):
             else:
                 cluster_id = shard_id = instance_type = None
 
-            db_info = DBInstance.create(name=name, flavor_id=flavor_id,
-                                        tenant_id=context.tenant,
-                                        volume_size=volume_size,
-                                        datastore_version_id=
-                                        datastore_version.id,
-                                        task_status=InstanceTasks.BUILDING,
-                                        configuration_id=configuration_id,
-                                        slave_of_id=slave_of_id,
-                                        cluster_id=cluster_id,
-                                        shard_id=shard_id,
-                                        type=instance_type)
-            LOG.debug("Tenant %(tenant)s created new Trove instance %(db)s."
-                      % {'tenant': context.tenant, 'db': db_info.id})
-
-            # if a configuration group is associated with an instance,
-            # generate an overrides dict to pass into the instance creation
-            # method
-
-            config = Configuration(context, configuration_id)
-            overrides = config.get_configuration_overrides()
-            service_status = InstanceServiceStatus.create(
-                instance_id=db_info.id,
-                status=tr_instance.ServiceStatuses.NEW)
-
-            if CONF.trove_dns_support:
-                dns_client = create_dns_client(context)
-                hostname = dns_client.determine_hostname(db_info.id)
-                db_info.hostname = hostname
-                db_info.save()
-
+            ids = []
+            names = []
+            root_passwords = []
             root_password = None
-            if cls.get_root_on_create(
-                    datastore_version.manager) and not backup_id:
-                root_password = utils.generate_random_password()
+            for instance_index in range(0, instance_count):
+                db_info = DBInstance.create(name=name, flavor_id=flavor_id,
+                                            tenant_id=context.tenant,
+                                            volume_size=volume_size,
+                                            datastore_version_id=
+                                            datastore_version.id,
+                                            task_status=InstanceTasks.BUILDING,
+                                            configuration_id=configuration_id,
+                                            slave_of_id=slave_of_id,
+                                            cluster_id=cluster_id,
+                                            shard_id=shard_id,
+                                            type=instance_type)
+                LOG.debug("Tenant %(tenant)s created new Trove instance "
+                          "%(db)s.",
+                          {'tenant': context.tenant, 'db': db_info.id})
 
-            task_api.API(context).create_instance(db_info.id, name, flavor,
-                                                  image_id, databases, users,
-                                                  datastore_version.manager,
-                                                  datastore_version.packages,
-                                                  volume_size, backup_id,
-                                                  availability_zone,
-                                                  root_password, nics,
-                                                  overrides, slave_of_id,
-                                                  cluster_config)
+                instance_id = db_info.id
+                instance_name = name
+                ids.append(instance_id)
+                names.append(instance_name)
+                root_passwords.append(None)
+                # change the name to be name + replica_number if more than one
+                if multi_replica:
+                    replica_number = instance_index + 1
+                    names[instance_index] += '-' + str(replica_number)
+                    setattr(db_info, 'name', names[instance_index])
+                    db_info.save()
+
+                # if a configuration group is associated with an instance,
+                # generate an overrides dict to pass into the instance creation
+                # method
+
+                config = Configuration(context, configuration_id)
+                overrides = config.get_configuration_overrides()
+                service_status = InstanceServiceStatus.create(
+                    instance_id=instance_id,
+                    status=tr_instance.ServiceStatuses.NEW)
+
+                if CONF.trove_dns_support:
+                    dns_client = create_dns_client(context)
+                    hostname = dns_client.determine_hostname(instance_id)
+                    db_info.hostname = hostname
+                    db_info.save()
+
+                if cls.get_root_on_create(
+                        datastore_version.manager) and not backup_id:
+                    root_password = utils.generate_random_password()
+                    root_passwords[instance_index] = root_password
+
+            if instance_count > 1:
+                instance_id = ids
+                instance_name = names
+                root_password = root_passwords
+            task_api.API(context).create_instance(
+                instance_id, instance_name, flavor, image_id, databases, users,
+                datastore_version.manager, datastore_version.packages,
+                volume_size, backup_id, availability_zone, root_password,
+                nics, overrides, slave_of_id, cluster_config)
 
             return SimpleInstance(context, db_info, service_status,
                                   root_password)
@@ -779,7 +846,7 @@ class Instance(BuiltInstance):
     def get_default_configuration_template(self):
         flavor = self.get_flavor()
         LOG.debug("Getting default config template for datastore version "
-                  "%(ds_version)s and flavor %(flavor)s." %
+                  "%(ds_version)s and flavor %(flavor)s.",
                   {'ds_version': self.ds_version, 'flavor': flavor})
         config = template.SingleInstanceConfigTemplate(
             self.ds_version, flavor, id)
@@ -787,47 +854,44 @@ class Instance(BuiltInstance):
 
     def resize_flavor(self, new_flavor_id):
         self.validate_can_perform_action()
-        LOG.info(_("Resizing instance %(instance_id)s flavor to "
-                   "%(flavor_id)s.")
-                 % {'instance_id': self.id, 'flavor_id': new_flavor_id})
+        LOG.info(_LI("Resizing instance %(instance_id)s flavor to "
+                     "%(flavor_id)s."),
+                 {'instance_id': self.id, 'flavor_id': new_flavor_id})
         if self.db_info.cluster_id is not None:
             raise exception.ClusterInstanceOperationNotSupported()
-        # Validate that the flavor can be found and that it isn't the same size
-        # as the current one.
+
+        # Validate that the old and new flavor IDs are not the same, new flavor
+        # can be found and has ephemeral/volume support if required by the
+        # current flavor.
+        if self.flavor_id == new_flavor_id:
+            raise exception.BadRequest(_("The new flavor id must be different "
+                                         "than the current flavor id of '%s'.")
+                                       % self.flavor_id)
         client = create_nova_client(self.context)
         try:
             new_flavor = client.flavors.get(new_flavor_id)
         except nova_exceptions.NotFound:
             raise exception.FlavorNotFound(uuid=new_flavor_id)
+
         old_flavor = client.flavors.get(self.flavor_id)
-        new_flavor_size = new_flavor.ram
-        old_flavor_size = old_flavor.ram
         if self.volume_support:
             if new_flavor.ephemeral != 0:
                 raise exception.LocalStorageNotSupported()
-            if new_flavor_size == old_flavor_size:
-                raise exception.CannotResizeToSameSize()
         elif self.device_path is not None:
             # ephemeral support enabled
             if new_flavor.ephemeral == 0:
                 raise exception.LocalStorageNotSpecified(flavor=new_flavor_id)
-            if (new_flavor_size == old_flavor_size and
-                    new_flavor.ephemeral == new_flavor.ephemeral):
-                raise exception.CannotResizeToSameSize()
-        elif new_flavor_size == old_flavor_size:
-            # uses local storage
-            raise exception.CannotResizeToSameSize()
 
         # Set the task to RESIZING and begin the async call before returning.
         self.update_db(task_status=InstanceTasks.RESIZING)
-        LOG.debug("Instance %s set to RESIZING." % self.id)
+        LOG.debug("Instance %s set to RESIZING.", self.id)
         task_api.API(self.context).resize_flavor(self.id, old_flavor,
                                                  new_flavor)
 
     def resize_volume(self, new_size):
         def _resize_resources():
             self.validate_can_perform_action()
-            LOG.info(_("Resizing volume of instance %s.") % self.id)
+            LOG.info(_LI("Resizing volume of instance %s."), self.id)
             if self.db_info.cluster_id is not None:
                 raise exception.ClusterInstanceOperationNotSupported()
             old_size = self.volume_size
@@ -850,7 +914,7 @@ class Instance(BuiltInstance):
 
     def reboot(self):
         self.validate_can_perform_action()
-        LOG.info(_("Rebooting instance %s.") % self.id)
+        LOG.info(_LI("Rebooting instance %s."), self.id)
         if self.db_info.cluster_id is not None and not self.context.is_admin:
             raise exception.ClusterInstanceOperationNotSupported()
         self.update_db(task_status=InstanceTasks.REBOOTING)
@@ -858,7 +922,7 @@ class Instance(BuiltInstance):
 
     def restart(self):
         self.validate_can_perform_action()
-        LOG.info(_("Restarting datastore on instance %s.") % self.id)
+        LOG.info(_LI("Restarting datastore on instance %s."), self.id)
         if self.db_info.cluster_id is not None and not self.context.is_admin:
             raise exception.ClusterInstanceOperationNotSupported()
         # Set our local status since Nova might not change it quick enough.
@@ -872,18 +936,56 @@ class Instance(BuiltInstance):
 
     def detach_replica(self):
         self.validate_can_perform_action()
-        LOG.info(_("Detaching instance %s from its replication source.")
-                 % self.id)
+        LOG.info(_LI("Detaching instance %s from its replication source."),
+                 self.id)
         if not self.slave_of_id:
             raise exception.BadRequest(_("Instance %s is not a replica.")
                                        % self.id)
         task_api.API(self.context).detach_replica(self.id)
 
+    def promote_to_replica_source(self):
+        self.validate_can_perform_action()
+        LOG.info(_LI("Promoting instance %s to replication source."), self.id)
+        if not self.slave_of_id:
+            raise exception.BadRequest(_("Instance %s is not a replica.")
+                                       % self.id)
+
+        # Update task status of master and all slaves
+        master = BuiltInstance.load(self.context, self.slave_of_id)
+        for dbinfo in [master.db_info] + master.slaves:
+            setattr(dbinfo, 'task_status', InstanceTasks.PROMOTING)
+            dbinfo.save()
+
+        task_api.API(self.context).promote_to_replica_source(self.id)
+
+    def eject_replica_source(self):
+        self.validate_can_perform_action()
+        LOG.info(_LI("Ejecting replica source %s from it's replication set."),
+                 self.id)
+
+        if not self.slaves:
+            raise exception.BadRequest(_("Instance %s is not a replica"
+                                       " source.") % self.id)
+        service = InstanceServiceStatus.find_by(instance_id=self.id)
+        last_heartbeat_delta = datetime.utcnow() - service.updated_at
+        agent_expiry_interval = timedelta(seconds=CONF.agent_heartbeat_expiry)
+        if last_heartbeat_delta < agent_expiry_interval:
+            raise exception.BadRequest(_("Replica Source %s cannot be ejected"
+                                         " as it has a current heartbeat")
+                                       % self.id)
+
+        # Update task status of master and all slaves
+        for dbinfo in [self.db_info] + self.slaves:
+            setattr(dbinfo, 'task_status', InstanceTasks.EJECTING)
+            dbinfo.save()
+
+        task_api.API(self.context).eject_replica_source(self.id)
+
     def migrate(self, host=None):
         self.validate_can_perform_action()
-        LOG.info(_("Migrating instance id = %(instance_id)s "
-                   "to host = %(host)s.")
-                 % {'instance_id': self.id, 'host': host})
+        LOG.info(_LI("Migrating instance id = %(instance_id)s "
+                     "to host = %(host)s."),
+                 {'instance_id': self.id, 'host': host})
         self.update_db(task_status=InstanceTasks.MIGRATING)
         task_api.API(self.context).migrate(self.id, host)
 
@@ -934,11 +1036,11 @@ class Instance(BuiltInstance):
                                                  status=status)
 
     def unassign_configuration(self):
-        LOG.debug("Unassigning the configuration from the instance %s."
-                  % self.id)
+        LOG.debug("Unassigning the configuration from the instance %s.",
+                  self.id)
         if self.configuration and self.configuration.id:
-            LOG.debug("Unassigning the configuration id %s."
-                      % self.configuration.id)
+            LOG.debug("Unassigning the configuration id %s.",
+                      self.configuration.id)
             flavor = self.get_flavor()
             config_id = self.configuration.id
             LOG.debug("Configuration being unassigned; "
@@ -968,17 +1070,17 @@ class Instance(BuiltInstance):
                 instance_datastore_version=inst_ds_v)
 
         config = Configuration(self.context, configuration.id)
-        LOG.debug("Config config is %s." % config)
+        LOG.debug("Config config is %s.", config)
         self.update_db(configuration_id=configuration.id)
         self.update_overrides(config)
 
     def update_overrides(self, config):
-        LOG.debug("Updating or removing overrides for instance %s."
-                  % self.id)
+        LOG.debug("Updating or removing overrides for instance %s.",
+                  self.id)
         overrides = config.get_configuration_overrides()
         need_restart = config.does_configuration_need_restart()
         LOG.debug("Config overrides has non-dynamic settings, "
-                  "requires a restart: %s." % need_restart)
+                  "requires a restart: %s.", need_restart)
         if need_restart:
             self.update_db(task_status=InstanceTasks.RESTART_REQUIRED)
         task_api.API(self.context).update_overrides(self.id, overrides)
@@ -998,9 +1100,9 @@ def create_server_list_matcher(server_list):
                 instance_id=instance_id, server_id=server_id)
         else:
             # Should never happen, but never say never.
-            LOG.error(_("Server %(server)s for instance %(instance)s was "
-                        "found twice!") % {'server': server_id,
-                                           'instance': instance_id})
+            LOG.error(_LE("Server %(server)s for instance %(instance)s was "
+                          "found twice!"), {'server': server_id,
+                                            'instance': instance_id})
             raise exception.TroveError(uuid=instance_id)
 
     return find_server
@@ -1038,7 +1140,7 @@ class Instances(object):
         find_server = create_server_list_matcher(servers)
         for db in db_infos:
             LOG.debug("Checking for db [id=%(db_id)s, "
-                      "compute_instance_id=%(instance_id)s]." %
+                      "compute_instance_id=%(instance_id)s].",
                       {'db_id': db.id, 'instance_id': db.compute_instance_id})
         ret = Instances._load_servers_status(load_simple_instance, context,
                                              data_view.collection,
@@ -1077,14 +1179,14 @@ class Instances(object):
                 datastore_status = InstanceServiceStatus.find_by(
                     instance_id=db.id)
                 if not datastore_status.status:  # This should never happen.
-                    LOG.error(_("Server status could not be read for "
-                                "instance id(%s).") % db.id)
+                    LOG.error(_LE("Server status could not be read for "
+                                  "instance id(%s)."), db.id)
                     continue
-                LOG.debug("Server api_status(%s)." %
+                LOG.debug("Server api_status(%s).",
                           datastore_status.status.api_status)
             except exception.ModelNotFoundError:
-                LOG.error(_("Server status could not be read for "
-                            "instance id(%s).") % db.id)
+                LOG.error(_LE("Server status could not be read for "
+                              "instance id(%s)."), db.id)
                 continue
             ret.append(load_instance(context, db, datastore_status,
                                      server=server))
