@@ -15,6 +15,8 @@
 
 import webob.exc
 
+from oslo.utils import strutils
+
 from trove.common import cfg
 from trove.common import exception
 from trove.common import pagination
@@ -27,7 +29,8 @@ from trove.datastore import models as datastore_models
 from trove.backup.models import Backup as backup_model
 from trove.backup import views as backup_views
 from trove.openstack.common import log as logging
-from trove.openstack.common.gettextutils import _
+from trove.common.i18n import _
+from trove.common.i18n import _LI
 import trove.common.apischema as apischema
 
 
@@ -67,7 +70,7 @@ class InstanceController(wsgi.Controller):
         :param tenant_id: the tenant id for whom owns the instance
         :param id: ???
         """
-        LOG.debug("instance action req : '%s'\n\n" % req)
+        LOG.debug("instance action req : '%s'\n\n", req)
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
         context = req.environ[wsgi.CONTEXT_KEY]
@@ -76,6 +79,9 @@ class InstanceController(wsgi.Controller):
             'restart': self._action_restart,
             'resize': self._action_resize,
             'reset_password': self._action_reset_password,
+            'promote_to_replica_source':
+            self._action_promote_to_replica_source,
+            'eject_replica_source': self._action_eject_replica_source,
         }
         selected_action = None
         action_name = None
@@ -83,10 +89,10 @@ class InstanceController(wsgi.Controller):
             if key in _actions:
                 selected_action = _actions[key]
                 action_name = key
-        LOG.info(_("Performing %(action_name)s action against "
-                   "instance %(instance_id)s for tenant '%(tenant_id)s'")
-                 % {'action_name': action_name, 'instance_id': id,
-                    'tenant_id': tenant_id})
+        LOG.info(_LI("Performing %(action_name)s action against "
+                     "instance %(instance_id)s for tenant '%(tenant_id)s'"),
+                 {'action_name': action_name, 'instance_id': id,
+                  'tenant_id': tenant_id})
         return selected_action(instance, body)
 
     def _action_restart(self, instance, body):
@@ -128,10 +134,18 @@ class InstanceController(wsgi.Controller):
     def _action_reset_password(self, instance, body):
         raise webob.exc.HTTPNotImplemented()
 
+    def _action_promote_to_replica_source(self, instance, body):
+        instance.promote_to_replica_source()
+        return wsgi.Result(None, 202)
+
+    def _action_eject_replica_source(self, instance, body):
+        instance.eject_replica_source()
+        return wsgi.Result(None, 202)
+
     def index(self, req, tenant_id):
         """Return all instances."""
-        LOG.info(_("Listing database instances for tenant '%s'") % tenant_id)
-        LOG.debug("req : '%s'\n\n" % req)
+        LOG.info(_LI("Listing database instances for tenant '%s'"), tenant_id)
+        LOG.debug("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         clustered_q = req.GET.get('include_clustered', '').lower()
         include_clustered = clustered_q == 'true'
@@ -143,9 +157,9 @@ class InstanceController(wsgi.Controller):
 
     def backups(self, req, tenant_id, id):
         """Return all backups for the specified instance."""
-        LOG.info(_("Listing backups for instance '%s'") %
+        LOG.info(_LI("Listing backups for instance '%s'"),
                  id)
-        LOG.debug("req : '%s'\n\n" % req)
+        LOG.debug("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         backups, marker = backup_model.list_for_instance(context, id)
         view = backup_views.BackupViews(backups)
@@ -155,10 +169,10 @@ class InstanceController(wsgi.Controller):
 
     def show(self, req, tenant_id, id):
         """Return a single instance."""
-        LOG.info(_("Showing database instance '%(instance_id)s' for tenant "
-                   "'%(tenant_id)s'") %
+        LOG.info(_LI("Showing database instance '%(instance_id)s' for tenant "
+                     "'%(tenant_id)s'"),
                  {'instance_id': id, 'tenant_id': tenant_id})
-        LOG.debug("req : '%s'\n\n" % req)
+        LOG.debug("req : '%s'\n\n", req)
 
         context = req.environ[wsgi.CONTEXT_KEY]
         server = models.load_instance_with_guest(models.DetailInstance,
@@ -168,10 +182,10 @@ class InstanceController(wsgi.Controller):
 
     def delete(self, req, tenant_id, id):
         """Delete a single instance."""
-        LOG.info(_("Deleting database instance '%(instance_id)s' for tenant "
-                   "'%(tenant_id)s'") %
+        LOG.info(_LI("Deleting database instance '%(instance_id)s' for tenant "
+                     "'%(tenant_id)s'"),
                  {'instance_id': id, 'tenant_id': tenant_id})
-        LOG.debug("req : '%s'\n\n" % req)
+        LOG.debug("req : '%s'\n\n", req)
         # TODO(hub-cap): turn this into middleware
         context = req.environ[wsgi.CONTEXT_KEY]
         instance = models.load_any_instance(context, id)
@@ -181,9 +195,10 @@ class InstanceController(wsgi.Controller):
 
     def create(self, req, body, tenant_id):
         # TODO(hub-cap): turn this into middleware
-        LOG.info(_("Creating a database instance for tenant '%s'") % tenant_id)
-        LOG.debug(logging.mask_password("req : '%s'\n\n" % req))
-        LOG.debug(logging.mask_password("body : '%s'\n\n" % body))
+        LOG.info(_LI("Creating a database instance for tenant '%s'"),
+                 tenant_id)
+        LOG.debug("req : '%s'\n\n", strutils.mask_password(req))
+        LOG.debug("body : '%s'\n\n", strutils.mask_password(body))
         context = req.environ[wsgi.CONTEXT_KEY]
         datastore_args = body['instance'].get('datastore', {})
         datastore, datastore_version = (
@@ -221,13 +236,14 @@ class InstanceController(wsgi.Controller):
         slave_of_id = body['instance'].get('replica_of',
                                            # also check for older name
                                            body['instance'].get('slave_of'))
-
+        replica_count = body['instance'].get('replica_count')
         instance = models.Instance.create(context, name, flavor_id,
                                           image_id, databases, users,
                                           datastore, datastore_version,
                                           volume_size, backup_id,
                                           availability_zone, nics,
-                                          configuration, slave_of_id)
+                                          configuration, slave_of_id,
+                                          replica_count=replica_count)
 
         view = views.InstanceDetailView(instance, req=req)
         return wsgi.Result(view.data(), 200)
@@ -239,57 +255,74 @@ class InstanceController(wsgi.Controller):
                 configuration_id = utils.get_id_from_href(configuration_ref)
                 return configuration_id
 
+    def _modify_instance(self, instance, **kwargs):
+        """Modifies the instance using the specified keyword arguments
+        'detach_replica': ignored if not present or False, if True,
+        specifies the instance is a replica that will be detached from
+        its master
+        'configuration_id': Ignored if not present, if None, detaches an
+        an attached configuration group, if not None, attaches the
+        specified configuration group
+        """
+
+        if 'detach_replica' in kwargs and kwargs['detach_replica']:
+            LOG.debug("Detaching replica from source.")
+            instance.detach_replica()
+        if 'configuration_id' in kwargs:
+            if kwargs['configuration_id']:
+                instance.assign_configuration(kwargs['configuration_id'])
+            else:
+                instance.unassign_configuration()
+        if kwargs:
+            instance.update_db(**kwargs)
+
     def update(self, req, id, body, tenant_id):
         """Updates the instance to attach/detach configuration."""
-        LOG.info(_("Updating database instance '%(instance_id)s' for tenant "
-                   "'%(tenant_id)s'") %
+        LOG.info(_LI("Updating database instance '%(instance_id)s' for tenant "
+                     "'%(tenant_id)s'"),
                  {'instance_id': id, 'tenant_id': tenant_id})
-        LOG.debug("req: %s" % req)
-        LOG.debug("body: %s" % body)
+        LOG.debug("req: %s", req)
+        LOG.debug("body: %s", body)
         context = req.environ[wsgi.CONTEXT_KEY]
 
         instance = models.Instance.load(context, id)
 
-        # if configuration is set, then we will update the instance to use
-        # the new configuration.  If configuration is empty, we want to
-        # disassociate the instance from the configuration group and remove the
-        # active overrides file.
-
-        configuration_id = self._configuration_parse(context, body)
-
-        if configuration_id:
-            instance.assign_configuration(configuration_id)
-        else:
-            instance.unassign_configuration()
+        # Make sure args contains a 'configuration_id' argument,
+        args = {}
+        args['configuration_id'] = self._configuration_parse(context, body)
+        self._modify_instance(instance, **args)
         return wsgi.Result(None, 202)
 
     def edit(self, req, id, body, tenant_id):
         """
         Updates the instance to set or unset one or more attributes.
         """
-        LOG.info(_("Editing instance for tenant id %s.") % tenant_id)
-        LOG.debug(logging.mask_password("req: %s"), req)
-        LOG.debug(logging.mask_password("body: %s"), body)
+        LOG.info(_LI("Editing instance for tenant id %s."), tenant_id)
+        LOG.debug("req: %s", strutils.mask_password(req))
+        LOG.debug("body: %s", strutils.mask_password(body))
         context = req.environ[wsgi.CONTEXT_KEY]
 
         instance = models.Instance.load(context, id)
 
-        if 'slave_of' in body['instance']:
-            LOG.debug("Detaching replica from source.")
-            instance.detach_replica()
-
+        args = {}
+        args['detach_replica'] = 'slave_of' in body['instance']
+        if 'name' in body['instance']:
+            args['name'] = body['instance']['name']
+        if 'configuration' in body['instance']:
+            args['configuration_id'] = self._configuration_parse(context, body)
+        self._modify_instance(instance, **args)
         return wsgi.Result(None, 202)
 
     def configuration(self, req, tenant_id, id):
         """
         Returns the default configuration template applied to the instance.
         """
-        LOG.info(_("Getting default configuration for instance %s") % id)
+        LOG.info(_LI("Getting default configuration for instance %s"), id)
         context = req.environ[wsgi.CONTEXT_KEY]
         instance = models.Instance.load(context, id)
-        LOG.debug("Server: %s" % instance)
+        LOG.debug("Server: %s", instance)
         config = instance.get_default_configuration_template()
-        LOG.debug("Default config for instance %(instance_id)s is %(config)s" %
+        LOG.debug("Default config for instance %(instance_id)s is %(config)s",
                   {'instance_id': id, 'config': config})
         return wsgi.Result(views.DefaultConfigurationView(
                            config).data(), 200)
