@@ -21,14 +21,17 @@ from cinderclient import exceptions as cinder_exceptions
 from eventlet import greenthread
 from novaclient import exceptions as nova_exceptions
 
+from oslo.utils import timeutils
+
 from trove.backup import models as bkup_models
 from trove.backup.models import Backup
-from trove.backup.models import BackupState
 from trove.backup.models import DBBackup
+from trove.backup.state import BackupState
 from trove.cluster.models import Cluster
 from trove.cluster.models import DBCluster
 from trove.cluster import tasks
 from trove.common import cfg
+from trove.common import exception
 from trove.common import template
 from trove.common import utils
 from trove.common.utils import try_recover
@@ -42,7 +45,7 @@ from trove.common.exception import TroveError
 from trove.common.exception import VolumeCreationFailure
 from trove.common.instance import ServiceStatuses
 from trove.common import instance as rd_instance
-from trove.common import strategy
+from trove.common.strategies.cluster import strategy
 from trove.common.remote import create_dns_client
 from trove.common.remote import create_heat_client
 from trove.common.remote import create_cinder_client
@@ -61,11 +64,10 @@ from trove.instance.tasks import InstanceTasks
 from trove.instance.models import InstanceStatus
 from trove.instance.models import InstanceServiceStatus
 from trove.openstack.common import log as logging
-from trove.openstack.common.gettextutils import _
-from trove.openstack.common.notifier import api as notifier
-from trove.openstack.common import timeutils
+from trove.common.i18n import _
 from trove.quota.quota import run_with_quotas
 import trove.common.remote as remote
+from trove import rpc
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -141,8 +143,11 @@ class NotifyMixin(object):
         payload.update(kwargs)
         LOG.debug('Sending event: %(event_type)s, %(payload)s' %
                   {'event_type': event_type, 'payload': payload})
-        notifier.notify(self.context, publisher_id, event_type, 'INFO',
-                        payload)
+
+        notifier = rpc.get_notifier(
+            service="taskmanager", publisher_id=publisher_id)
+
+        notifier.info(self.context, event_type, payload)
 
 
 class ConfigurationMixin(object):
@@ -183,7 +188,6 @@ class ConfigurationMixin(object):
         return ret
 
 
-# TODO(amcreynolds): add NotifyMixin + ConfigurationMixin-like functionality
 class ClusterTasks(Cluster):
 
     def delete_cluster(self, context, cluster_id):
@@ -213,10 +217,59 @@ class ClusterTasks(Cluster):
 
 
 class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
+
+    def _get_injected_files(self, datastore_manager):
+        injected_config_location = CONF.get('injected_config_location')
+        guest_info = CONF.get('guest_info')
+
+        if ('/' in guest_info):
+            # Set guest_info_file to exactly guest_info from the conf file.
+            # This should be /etc/guest_info for pre-Kilo compatibility.
+            guest_info_file = guest_info
+        else:
+            guest_info_file = os.path.join(injected_config_location,
+                                           guest_info)
+
+        files = {guest_info_file: (
+            "[DEFAULT]\n"
+            "guest_id=%s\n"
+            "datastore_manager=%s\n"
+            "tenant_id=%s\n"
+            % (self.id, datastore_manager, self.tenant_id))}
+
+        if os.path.isfile(CONF.get('guest_config')):
+            with open(CONF.get('guest_config'), "r") as f:
+                files[os.path.join(injected_config_location,
+                                   "trove-guestagent.conf")] = f.read()
+
+        return files
+
+    def wait_for_instance(self, timeout, flavor):
+        # Make sure the service becomes active before sending a usage
+        # record to avoid over billing a customer for an instance that
+        # fails to build properly.
+        try:
+            utils.poll_until(self._service_is_active,
+                             sleep_time=USAGE_SLEEP_TIME,
+                             time_out=timeout)
+            LOG.info(_("Created instance %s successfully.") % self.id)
+            self.send_usage_event('create', instance_size=flavor['ram'])
+        except PollTimeOut:
+            LOG.error(_("Failed to create instance %s. "
+                        "Timeout waiting for instance to become active. "
+                        "No usage create-event was sent.") % self.id)
+            self.update_statuses_on_time_out()
+        except Exception:
+            LOG.exception(_("Failed to send usage create-event for "
+                            "instance %s.") % self.id)
+
     def create_instance(self, flavor, image_id, databases, users,
                         datastore_manager, packages, volume_size,
                         backup_id, availability_zone, root_password, nics,
-                        overrides, cluster_config):
+                        overrides, cluster_config, snapshot=None):
+        # It is the caller's responsibility to ensure that
+        # FreshInstanceTasks.wait_for_instance is called after
+        # create_instance to ensure that the proper usage event gets sent
 
         LOG.info(_("Creating instance %s.") % self.id)
         security_groups = None
@@ -238,6 +291,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 LOG.debug("Successfully created security group for "
                           "instance: %s" % self.id)
 
+        files = self._get_injected_files(datastore_manager)
+
         if use_heat:
             volume_info = self._create_server_volume_heat(
                 flavor,
@@ -245,7 +300,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 datastore_manager,
                 volume_size,
                 availability_zone,
-                nics)
+                nics,
+                files)
         elif use_nova_server_volume:
             volume_info = self._create_server_volume(
                 flavor['id'],
@@ -254,7 +310,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 datastore_manager,
                 volume_size,
                 availability_zone,
-                nics)
+                nics,
+                files)
         else:
             volume_info = self._create_server_volume_individually(
                 flavor['id'],
@@ -263,10 +320,9 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 datastore_manager,
                 volume_size,
                 availability_zone,
-                nics)
+                nics,
+                files)
 
-        # TODO(amcreynolds): need to find a way to merge cluster_config
-        # TODO(amcreynolds): into config_contents
         config = self._render_config(flavor)
         config_overrides = self._render_override_config(flavor,
                                                         overrides=overrides)
@@ -283,7 +339,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                             packages, databases, users, backup_info,
                             config.config_contents, root_password,
                             config_overrides.config_contents,
-                            cluster_config)
+                            cluster_config, snapshot)
 
         if root_password:
             self.report_root_enabled()
@@ -305,26 +361,6 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             LOG.debug("Successfully created DNS entry for instance: %s" %
                       self.id)
 
-        # Make sure the service becomes active before sending a usage
-        # record to avoid over billing a customer for an instance that
-        # fails to build properly.
-        try:
-            timeout = (CONF.restore_usage_timeout if backup_info
-                       else CONF.usage_timeout)
-            utils.poll_until(self._service_is_active,
-                             sleep_time=USAGE_SLEEP_TIME,
-                             time_out=timeout)
-            LOG.info(_("Created instance %s successfully.") % self.id)
-            self.send_usage_event('create', instance_size=flavor['ram'])
-        except PollTimeOut:
-            LOG.error(_("Failed to create instance %s. "
-                        "Timeout waiting for instance to become active. "
-                        "No usage create-event was sent.") % self.id)
-            self.update_statuses_on_time_out()
-        except Exception:
-            LOG.exception(_("Failed to send usage create-event for "
-                            "instance %s.") % self.id)
-
     def attach_replication_slave(self, snapshot, flavor):
         LOG.debug("Calling attach_replication_slave for %s.", self.id)
         try:
@@ -337,48 +373,93 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             err = inst_models.InstanceTasks.BUILDING_ERROR_REPLICA
             self._log_and_raise(e, msg, err)
 
-    def get_replication_master_snapshot(self, context, slave_of_id):
+    def get_replication_master_snapshot(self, context, slave_of_id, flavor,
+                                        backup_id=None, replica_number=1):
+        # if we aren't passed in a backup id, look it up to possibly do
+        # an incremental backup, thus saving time
+        if not backup_id:
+            backup = Backup.get_last_completed(
+                context, slave_of_id, include_incremental=True)
+            if backup:
+                backup_id = backup.id
         snapshot_info = {
-            'name': "Replication snapshot of %s" % self.id,
+            'name': "Replication snapshot for %s" % self.id,
             'description': "Backup image used to initialize "
-            "replication slave",
+                           "replication slave",
             'instance_id': slave_of_id,
-            'parent_id': None,
+            'parent_id': backup_id,
             'tenant_id': self.tenant_id,
             'state': BackupState.NEW,
             'datastore_version_id': self.datastore_version.id,
-            'deleted': False
+            'deleted': False,
+            'replica_number': replica_number,
         }
 
-        try:
-            db_info = DBBackup.create(**snapshot_info)
-        except InvalidModelError as e:
-            msg = (_("Unable to create replication snapshot record for "
-                     "instance: %s") % self.id)
-            LOG.exception(msg)
-            raise BackupCreationError(msg)
+        # Only do a backup if it's the first replica
+        if replica_number == 1:
+            try:
+                db_info = DBBackup.create(**snapshot_info)
+                replica_backup_id = db_info.id
+            except InvalidModelError:
+                msg = (_("Unable to create replication snapshot record for "
+                         "instance: %s") % self.id)
+                LOG.exception(msg)
+                raise BackupCreationError(msg)
+            if backup_id:
+                # Look up the parent backup  info or fail early if not found or
+                # if the user does not have access to the parent.
+                _parent = Backup.get_by_id(context, backup_id)
+                parent = {
+                    'location': _parent.location,
+                    'checksum': _parent.checksum,
+                }
+                snapshot_info.update({
+                    'parent': parent,
+                })
+        else:
+            # we've been passed in the actual replica backup id, so just use it
+            replica_backup_id = backup_id
 
         try:
             master = BuiltInstanceTasks.load(context, slave_of_id)
             snapshot_info.update({
-                'id': db_info['id'],
+                'id': replica_backup_id,
                 'datastore': master.datastore.name,
                 'datastore_version': master.datastore_version.name,
             })
             snapshot = master.get_replication_snapshot(
                 snapshot_info, flavor=master.flavor_id)
+            snapshot.update({
+                'config': self._render_replica_config(flavor).config_contents
+            })
             return snapshot
-        except TroveError as e:
-            msg = (_("Error creating replication snapshot "
-                     "from instance %(source)s "
-                     "for new replica %(replica)s.") % {'source': slave_of_id,
-                                                        'replica': self.id})
+        except Exception as e_create:
+            msg_create = (
+                _("Error creating replication snapshot from "
+                  "instance %(source)s for new replica %(replica)s.") %
+                {'source': slave_of_id, 'replica': self.id})
             err = inst_models.InstanceTasks.BUILDING_ERROR_REPLICA
-            Backup.delete(context, snapshot_info['id'])
-            self._log_and_raise(e, msg, err)
-        except Exception:
-            Backup.delete(context, snapshot_info['id'])
-            raise
+            # if the delete of the 'bad' backup fails, it'll mask the
+            # create exception, so we trap it here
+            try:
+                # Only try to delete the backup if it's the first replica
+                if replica_number == 1:
+                    Backup.delete(context, replica_backup_id)
+            except Exception as e_delete:
+                LOG.error(msg_create)
+                # Make sure we log any unexpected errors from the create
+                if not isinstance(e_create, TroveError):
+                    LOG.error(e_create)
+                msg_delete = (
+                    _("An error occurred while deleting a bad "
+                      "replication snapshot from instance %(source)s.") %
+                    {'source': slave_of_id})
+                # we've already logged the create exception, so we'll raise
+                # the delete (otherwise the create will be logged twice)
+                self._log_and_raise(e_delete, msg_delete, err)
+
+            # the delete worked, so just log the original problem with create
+            self._log_and_raise(e_create, msg_create, err)
 
     def report_root_enabled(self):
         mysql_models.RootHistory.create(self.context, self.id, 'root')
@@ -438,26 +519,23 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
     def _create_server_volume(self, flavor_id, image_id, security_groups,
                               datastore_manager, volume_size,
-                              availability_zone, nics):
+                              availability_zone, nics, files):
         LOG.debug("Begin _create_server_volume for id: %s" % self.id)
         try:
-            files = {"/etc/guest_info": ("[DEFAULT]\n--guest_id="
-                                         "%s\n--datastore_manager=%s\n"
-                                         "--tenant_id=%s\n" %
-                                         (self.id, datastore_manager,
-                                          self.tenant_id))}
-
+            userdata = self._prepare_userdata(datastore_manager)
             name = self.hostname or self.name
             volume_desc = ("datastore volume for %s" % self.id)
             volume_name = ("datastore-%s" % self.id)
             volume_ref = {'size': volume_size, 'name': volume_name,
                           'description': volume_desc}
-
+            config_drive = CONF.use_nova_server_config_drive
             server = self.nova_client.servers.create(
                 name, image_id, flavor_id,
                 files=files, volume=volume_ref,
                 security_groups=security_groups,
-                availability_zone=availability_zone, nics=nics)
+                availability_zone=availability_zone,
+                nics=nics, config_drive=config_drive,
+                userdata=userdata)
             LOG.debug("Created new compute instance %(server_id)s "
                       "for id: %(id)s" %
                       {'server_id': server.id, 'id': self.id})
@@ -494,10 +572,9 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         return final
 
     def _create_server_volume_heat(self, flavor, image_id,
-                                   datastore_manager,
-                                   volume_size, availability_zone,
-                                   nics):
-        LOG.debug("begin _create_server_volume_heat for id: %s" % self.id)
+                                   datastore_manager, volume_size,
+                                   availability_zone, nics, files):
+        LOG.debug("Begin _create_server_volume_heat for id: %s" % self.id)
         try:
             client = create_heat_client(self.context)
             tcp_rules_mapping_list = self._build_sg_rules_mapping(CONF.get(
@@ -512,7 +589,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 ifaces=ifaces, ports=ports,
                 tcp_rules=tcp_rules_mapping_list,
                 udp_rules=udp_ports_mapping_list,
-                datastore_manager=datastore_manager)
+                datastore_manager=datastore_manager,
+                files=files)
             try:
                 heat_template = heat_template_unicode.encode('utf-8')
             except UnicodeEncodeError:
@@ -590,8 +668,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
     def _create_server_volume_individually(self, flavor_id, image_id,
                                            security_groups, datastore_manager,
-                                           volume_size,
-                                           availability_zone, nics):
+                                           volume_size, availability_zone,
+                                           nics, files):
         LOG.debug("Begin _create_server_volume_individually for id: %s" %
                   self.id)
         server = None
@@ -602,7 +680,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             server = self._create_server(flavor_id, image_id, security_groups,
                                          datastore_manager,
                                          block_device_mapping,
-                                         availability_zone, nics)
+                                         availability_zone, nics, files)
             server_id = server.id
             # Save server ID.
             self.update_db(compute_instance_id=server_id)
@@ -693,24 +771,19 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                        'volumes': created_volumes}
         return volume_info
 
-    def _create_server(self, flavor_id, image_id, security_groups,
-                       datastore_manager, block_device_mapping,
-                       availability_zone, nics):
-        files = {"/etc/guest_info": ("[DEFAULT]\nguest_id=%s\n"
-                                     "datastore_manager=%s\n"
-                                     "tenant_id=%s\n" %
-                                     (self.id, datastore_manager,
-                                      self.tenant_id))}
-
-        if os.path.isfile(CONF.get('guest_config')):
-            with open(CONF.get('guest_config'), "r") as f:
-                files["/etc/trove-guestagent.conf"] = f.read()
+    def _prepare_userdata(self, datastore_manager):
         userdata = None
         cloudinit = os.path.join(CONF.get('cloudinit_location'),
                                  "%s.cloudinit" % datastore_manager)
         if os.path.isfile(cloudinit):
             with open(cloudinit, "r") as f:
                 userdata = f.read()
+        return userdata
+
+    def _create_server(self, flavor_id, image_id, security_groups,
+                       datastore_manager, block_device_mapping,
+                       availability_zone, nics, files={}):
+        userdata = self._prepare_userdata(datastore_manager)
         name = self.hostname or self.name
         bdmap = block_device_mapping
         config_drive = CONF.use_nova_server_config_drive
@@ -728,8 +801,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
     def _guest_prepare(self, flavor_ram, volume_info,
                        packages, databases, users, backup_info=None,
                        config_contents=None, root_password=None,
-                       overrides=None, cluster_config=None):
-        LOG.info(_("Entering guest_prepare"))
+                       overrides=None, cluster_config=None, snapshot=None):
+        LOG.debug("Entering guest_prepare")
         # Now wait for the response from the create to do additional work
         self.guest.prepare(flavor_ram, packages, databases, users,
                            device_path=volume_info['device_path'],
@@ -738,7 +811,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                            config_contents=config_contents,
                            root_password=root_password,
                            overrides=overrides,
-                           cluster_config=cluster_config)
+                           cluster_config=cluster_config,
+                           snapshot=snapshot)
 
     def _create_dns_entry(self):
         dns_support = CONF.trove_dns_support
@@ -847,6 +921,13 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
         LOG.debug("Begin _delete_resources for instance %s" % self.id)
         server_id = self.db_info.compute_instance_id
         old_server = self.nova_client.servers.get(server_id)
+        LOG.debug("Stopping datastore on instance %s before deleting any "
+                  "resources." % self.id)
+        try:
+            self.guest.stop_db()
+        except Exception:
+            LOG.exception(_("Error stopping the datastore before attempting "
+                            "to delete instance id %s.") % self.id)
         try:
             if use_heat:
                 # Delete the server via heat
@@ -889,6 +970,19 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                             "Timeout deleting compute server %(server_id)s") %
                           {'instance_id': self.id, 'server_id': server_id})
 
+        # If volume has been resized it must be manually removed in cinder
+        try:
+            if self.volume_id:
+                volume_client = create_cinder_client(self.context)
+                volume = volume_client.volumes.get(self.volume_id)
+                if volume.status == "available":
+                    LOG.info(_("Deleting volume %(v)s for instance: %(i)s.")
+                             % {'v': self.volume_id, 'i': self.id})
+                    volume.delete()
+        except Exception:
+            LOG.exception(_("Error deleting volume of instance %(id)s.") %
+                          {'id': self.db_info.id})
+
         self.send_usage_event('delete',
                               deleted_at=timeutils.isotime(deleted_at),
                               server=old_server)
@@ -937,34 +1031,128 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                     snapshot_info, rep_source_config.config_contents)
                 LOG.debug("Got replication snapshot from guest successfully.")
                 return result
-            except (GuestError, GuestTimeout):
-                LOG.exception(_("Failed to get replication snapshot from %s") %
-                              self.id)
+            except Exception:
+                LOG.exception(_("Failed to get replication snapshot from %s.")
+                              % self.id)
                 raise
 
         return run_with_quotas(self.context.tenant, {'backups': 1},
                                _get_replication_snapshot)
 
-    def detach_replica(self, master):
+    def detach_replica(self, master, for_failover=False):
         LOG.debug("Calling detach_replica on %s" % self.id)
         try:
-            replica_info = self.guest.detach_replica()
-            master.cleanup_source_on_replica_detach(replica_info)
+            self.guest.detach_replica(for_failover)
             self.update_db(slave_of_id=None)
+            self.slave_list = None
         except (GuestError, GuestTimeout):
             LOG.exception(_("Failed to detach replica %s.") % self.id)
+            raise
+
+    def attach_replica(self, master):
+        LOG.debug("Calling attach_replica on %s" % self.id)
+        try:
+            replica_info = master.guest.get_replica_context()
+            flavor = self.nova_client.flavors.get(self.flavor_id)
+            slave_config = self._render_replica_config(flavor).config_contents
+            self.guest.attach_replica(replica_info, slave_config)
+            self.update_db(slave_of_id=master.id)
+            self.slave_list = None
+        except (GuestError, GuestTimeout):
+            LOG.exception(_("Failed to attach replica %s.") % self.id)
+            raise
+
+    def make_read_only(self, read_only):
+        LOG.debug("Calling make_read_only on %s" % self.id)
+        self.guest.make_read_only(read_only)
+
+    def _get_floating_ips(self):
+        """Returns floating ips as a dict indexed by the ip."""
+        floating_ips = {}
+        for ip in self.nova_client.floating_ips.list():
+            floating_ips.update({ip.ip: ip})
+        return floating_ips
+
+    def detach_public_ips(self):
+        LOG.debug("Begin detach_public_ips for instance %s" % self.id)
+        removed_ips = []
+        server_id = self.db_info.compute_instance_id
+        nova_instance = self.nova_client.servers.get(server_id)
+        floating_ips = self._get_floating_ips()
+        for ip in self.get_visible_ip_addresses():
+            if ip in floating_ips:
+                nova_instance.remove_floating_ip(ip)
+                removed_ips.append(ip)
+        return removed_ips
+
+    def attach_public_ips(self, ips):
+        LOG.debug("Begin attach_public_ips for instance %s" % self.id)
+        server_id = self.db_info.compute_instance_id
+        nova_instance = self.nova_client.servers.get(server_id)
+        for ip in ips:
+            nova_instance.add_floating_ip(ip)
+
+    def enable_as_master(self):
+        LOG.debug("Calling enable_as_master on %s" % self.id)
+        flavor = self.nova_client.flavors.get(self.flavor_id)
+        replica_source_config = self._render_replica_source_config(flavor)
+        self.update_db(slave_of_id=None)
+        self.slave_list = None
+        self.guest.enable_as_master(replica_source_config.config_contents)
+
+    def get_last_txn(self):
+        LOG.debug("Calling get_last_txn on %s" % self.id)
+        return self.guest.get_last_txn()
+
+    def get_latest_txn_id(self):
+        LOG.debug("Calling get_latest_txn_id on %s" % self.id)
+        return self.guest.get_latest_txn_id()
+
+    def wait_for_txn(self, txn):
+        LOG.debug("Calling wait_for_txn on %s" % self.id)
+        if txn:
+            self.guest.wait_for_txn(txn)
+
+    def switch_master(self, new_master):
+        LOG.debug("calling switch_master on %s" % self.id)
+
+        self.guest.switch_master(new_master)
+        self.update_db(slave_of_id=new_master.id)
+        self.slave_list = None
 
     def cleanup_source_on_replica_detach(self, replica_info):
         LOG.debug("Calling cleanup_source_on_replica_detach on %s" % self.id)
         self.guest.cleanup_source_on_replica_detach(replica_info)
 
+    def demote_replication_master(self):
+        LOG.debug("Calling demote_replication_master on %s" % self.id)
+        self.guest.demote_replication_master()
+
     def reboot(self):
         try:
+            # Issue a guest stop db call to shutdown the db if running
             LOG.debug("Stopping datastore on instance %s." % self.id)
-            self.guest.stop_db()
+            try:
+                self.guest.stop_db()
+            except (exception.GuestError, exception.GuestTimeout) as e:
+                # Acceptable to be here if db was already in crashed state
+                # Also we check guest state before issuing reboot
+                LOG.debug(str(e))
+
+            self._refresh_datastore_status()
+            if not (self.datastore_status_matches(
+                    rd_instance.ServiceStatuses.SHUTDOWN) or
+                    self.datastore_status_matches(
+                    rd_instance.ServiceStatuses.CRASHED)):
+                # We will bail if db did not get stopped or is blocked
+                LOG.error(_("Cannot reboot instance. DB status is %s.")
+                          % self.datastore_status.status)
+                return
+            LOG.debug("The guest service status is %s."
+                      % self.datastore_status.status)
+
             LOG.info(_("Rebooting instance %s.") % self.id)
             self.server.reboot()
-
             # Poll nova until instance is active
             reboot_time_out = CONF.reboot_time_out
 
@@ -1075,7 +1263,6 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 overrides[item.configuration_key] = _convert_value(val)
         LOG.debug("setting the default variables in dict: %s" % overrides)
         self.update_overrides(overrides, remove=True)
-        self.update_db(configuration_id=None)
 
     def refresh_compute_server_info(self):
         """Refreshes the compute server field."""
