@@ -131,7 +131,7 @@ class MalformedJson(object):
 
         poll_until(_check_instance_status)
         try:
-            self.dbaas.instances.resize_instance(self.instance.id, "bad data")
+            self.dbaas.instances.resize_instance(self.instance.id, "")
         except Exception as e:
             resp, body = self.dbaas.client.last_response
             httpCode = resp.status
@@ -165,7 +165,7 @@ class MalformedJson(object):
                  "resize['volume']['size'] %s is not valid under "
                  "any of the given schemas" % data,
                  "%s is not of type 'integer'" % data,
-                 "%s does not match '[0-9]+'" % data])
+                 "%s does not match '^[0-9]+$'" % data])
 
     @test
     def test_bad_change_user_password(self):
