@@ -12,32 +12,29 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import functools
 import json
 import time
+import logging
+import functools
 
-from oslo_log import log as logging
+from proboscis import before_class
+from proboscis import test
+from proboscis import SkipTest
+from proboscis import TestProgram
 from proboscis.asserts import assert_equal
 from proboscis.asserts import assert_true
 from proboscis.asserts import Check
-from proboscis import before_class
-from proboscis import SkipTest
-from proboscis import test
-from proboscis import TestProgram
-import six
-from troveclient.compat import client as trove_client
-from troveclient.compat import Dbaas
+
 from troveclient.compat import TroveHTTPClient
-
+from troveclient.compat import client as trove_client
 from trove.tests.config import CONFIG
-from trove.tests.examples.client import JsonClient
-from trove.tests.examples.client import SnippetWriter
 
-# troveclient.compat.client._logger was changed to LOG in 2.11.0
-if hasattr(trove_client, '_logger'):
-    trove_client._logger.setLevel(logging.CRITICAL)
-elif hasattr(trove_client, 'LOG'):
-    trove_client.LOG.setLevel(logging.CRITICAL)
+from troveclient.compat import Dbaas
+
+from trove.tests.examples.client import SnippetWriter
+from trove.tests.examples.client import JsonClient
+
+trove_client._logger.setLevel(logging.CRITICAL)
 
 FAKE_INFO = {'m': 30, 's': 0, 'uuid': 'abcdef00-aaaa-aaaa-aaaa-bbbbbbbbbbbb'}
 EXAMPLE_BACKUP_ID = "a9832168-7541-4536-b8d9-a8a9b79cf1b4"
@@ -75,9 +72,8 @@ def set_fake_stuff(uuid=None, minute=None, unique_id=None):
 def monkey_patch_uuid_and_date():
     import uuid
     uuid.uuid4 = get_uuid
-    from trove.common import timeutils
     from trove.common import utils
-    timeutils.utcnow = get_now
+    utils.utcnow = get_now
     utils.generate_uuid = get_uuid
 
 
@@ -172,10 +168,12 @@ def create_client(cls, user):
 
 
 def make_client(user):
+    #snippet_writer = SnippetWriter(conf)
     args, kwargs = create_client_args(user)
     kwargs['client_cls'] = JsonClient
     client = Dbaas(*args, **kwargs)
     client.client.name = "auth"
+    #client.client.snippet_writer = snippet_writer
     client.authenticate()
     return client
 
@@ -350,7 +348,8 @@ class Databases(Example):
             "POST", 202, "Accepted",
             lambda client: client.databases.create(
                 json_instance.id,
-                databases=[
+                databases=
+                [
                     {
                         "name": "testingdb",
                         "character_set": "utf8",
@@ -359,7 +358,8 @@ class Databases(Example):
                         "name": "anotherdb"
                     }, {
                         "name": "oneMoreDB"
-                    }]))
+                    }
+                ]))
 
     @test(depends_on=[post_create_databases])
     def get_list_databases(self):
@@ -503,17 +503,6 @@ class Root(Example):
             lambda client: client.root.is_root_enabled(json_instance.id))
         assert_equal(results[JSON_INDEX].rootEnabled, True)
 
-    @test(depends_on=[get_check_root_access])
-    def delete_disable_root_access(self):
-        self.snippet(
-            "disable_root_user",
-            "/instances/%s/root" % json_instance.id,
-            "DELETE", 200, "OK",
-            lambda client: client.root.delete(json_instance.id))
-
-        # restore root for subsequent tests
-        self.post_enable_root_access()
-
 
 class ActiveMixin(Example):
     """Adds a method to wait for instance status to become ACTIVE."""
@@ -846,7 +835,7 @@ class Backups(ActiveMixin):
         assert_equal(len(results), 1)
         self.json_backup = results[JSON_INDEX]
 
-    @test(depends_on=[create_backup])
+    @test
     def create_incremental_backup(self):
         set_fake_stuff(uuid=EXAMPLE_BACKUP_INCREMENTAL_ID)
         results = self.snippet(
@@ -861,9 +850,9 @@ class Backups(ActiveMixin):
 
         self._wait_for_active("BACKUP")
         assert_equal(len(results), 1)
-        self.json_backup2 = results[JSON_INDEX]
+        self.json_backup = results[JSON_INDEX]
 
-    @test(depends_on=[create_incremental_backup])
+    @test(depends_on=[create_backup])
     def get_backup(self):
         results = self.snippet(
             "backup_get",
@@ -872,7 +861,7 @@ class Backups(ActiveMixin):
             lambda client: client.backups.get(self.json_backup.id))
         assert_equal(len(results), 1)
 
-    @test(depends_on=[create_incremental_backup])
+    @test(depends_on=[create_backup])
     def get_backups_for_instance(self):
         results = self.snippet(
             "backups_by_instance",
@@ -881,7 +870,7 @@ class Backups(ActiveMixin):
             lambda client: client.instances.backups(json_instance.id))
         assert_equal(len(results), 1)
 
-    @test(depends_on=[create_incremental_backup])
+    @test(depends_on=[create_backup])
     def list_backups(self):
         results = self.snippet(
             "backup_list",
@@ -1014,12 +1003,10 @@ class MgmtHosts(Example):
                 check.equal(1, len(host.instances))
                 for instance in host.instances:
                     check.equal(instance['status'], 'ACTIVE')
-                    check.true(isinstance(instance['name'], six.string_types))
-                    check.true(isinstance(instance['id'], six.string_types))
-                    check.true(isinstance(instance['server_id'],
-                               six.string_types))
-                    check.true(isinstance(instance['tenant_id'],
-                               six.string_types))
+                    check.true(isinstance(instance['name'], basestring))
+                    check.true(isinstance(instance['id'], basestring))
+                    check.true(isinstance(instance['server_id'], basestring))
+                    check.true(isinstance(instance['tenant_id'], basestring))
 
     @test
     def mgmt_host_update_all(self):
@@ -1126,7 +1113,7 @@ class MgmtInstance(Example):
     @test
     @for_both
     def created(self, result):
-        assert_true(isinstance(result.created, six.string_types))
+        assert_true(isinstance(result.created, basestring))
 
     @test
     def deleted(self):
@@ -1161,8 +1148,8 @@ class MgmtInstance(Example):
         assert_true(isinstance(result.links, list))
         for link in result.links:
             assert_true(isinstance(link, dict))
-            assert_true(isinstance(link['href'], six.string_types))
-            assert_true(isinstance(link['rel'], six.string_types))
+            assert_true(isinstance(link['href'], basestring))
+            assert_true(isinstance(link['rel'], basestring))
 
     @test
     def local_id(self):
@@ -1172,12 +1159,12 @@ class MgmtInstance(Example):
     @test
     @for_both
     def name(self, result):
-        assert_true(isinstance(result.name, six.string_types))
+        assert_true(isinstance(result.name, basestring))
 
     @test
     @for_both
     def server_id(self, result):
-        assert_true(isinstance(result.server['id'], six.string_types))
+        assert_true(isinstance(result.server['id'], basestring))
 
     @test
     @for_both
@@ -1197,7 +1184,7 @@ class MgmtInstance(Example):
     @test
     @for_both
     def updated(self, result):
-        assert_true(isinstance(result.updated, six.string_types))
+        assert_true(isinstance(result.updated, basestring))
 
     @test
     @for_both
