@@ -15,14 +15,13 @@
 #
 
 from collections import defaultdict
-
 import eventlet
-from oslo_log import log as logging
 
-from trove import rpc
+import trove.openstack.common.log as logging
 from trove.taskmanager.api import API
 from trove.taskmanager.manager import Manager
 import trove.tests.util.usage as usage
+from trove import rpc
 
 LOG = logging.getLogger(__name__)
 MESSAGE_QUEUE = defaultdict(list)
@@ -38,10 +37,7 @@ class FakeRpcClient(object):
         manager, method = self._get_tm_method(method_name)
 
         def func():
-            try:
-                method(manager, context, *args, **kwargs)
-            except Exception:
-                LOG.exception("Error running %s", method)
+            method(manager, context, *args, **kwargs)
 
         eventlet.spawn_after(0.1, func)
 
