@@ -26,7 +26,7 @@ from trove.cluster.service import ClusterController
 from trove.cluster import views
 import trove.common.cfg as cfg
 from trove.common import exception
-from trove.common import strategy
+from trove.common.strategies.cluster import strategy
 from trove.common import utils
 from trove.datastore import models as datastore_models
 
@@ -179,6 +179,7 @@ class TestClusterController(TestCase):
 
         mock_cluster = Mock()
         mock_cluster.instances = []
+        mock_cluster.instances_without_server = []
         mock_cluster.datastore_version.manager = 'mongodb'
         mock_cluster_create.return_value = mock_cluster
 
@@ -199,6 +200,7 @@ class TestClusterController(TestCase):
 
         mock_cluster = Mock()
         mock_cluster.instances = []
+        mock_cluster.instances_without_server = []
         mock_cluster.datastore_version.manager = 'mongodb'
         mock_cluster_load.return_value = mock_cluster
 
