@@ -19,6 +19,7 @@ from testtools.matchers import Is, Equals
 from testtools.testcase import skip
 from trove.common import apischema
 from trove.instance.service import InstanceController
+from mock import Mock
 
 
 class TestInstanceController(TestCase):
@@ -134,6 +135,17 @@ class TestInstanceController(TestCase):
         self.assertThat(errors[0].message,
                         Equals("'     ' does not match '^.*[0-9a-zA-Z]+.*$'"))
 
+    def test_validate_create_invalid_name(self):
+        body = self.instance
+        body['instance']['name'] = "$#$%^^"
+        schema = self.controller.get_schema('create', body)
+        validator = jsonschema.Draft4Validator(schema)
+        self.assertFalse(validator.is_valid(body))
+        errors = sorted(validator.iter_errors(body), key=lambda e: e.path)
+        self.assertEqual(len(errors), 1)
+        self.assertIn("'$#$%^^' does not match '^.*[0-9a-zA-Z]+.*$'",
+                      errors[0].message)
+
     def test_validate_restart(self):
         body = {"restart": {}}
         schema = self.controller.get_schema('action', body)
@@ -154,12 +166,22 @@ class TestInstanceController(TestCase):
         self.assertTrue(validator.is_valid(body))
 
     def test_validate_resize_volume_string(self):
-        body = {"resize": {"volume": {"size": '-44.0'}}}
+        body = {"resize": {"volume": {"size": "4"}}}
         schema = self.controller.get_schema('action', body)
         validator = jsonschema.Draft4Validator(schema)
         self.assertTrue(validator.is_valid(body))
 
-    def test_validate_resize_volume_invalid(self):
+    def test_validate_resize_volume_string_invalid_number(self):
+        body = {"resize": {"volume": {"size": '-44.0'}}}
+        schema = self.controller.get_schema('action', body)
+        validator = jsonschema.Draft4Validator(schema)
+        self.assertFalse(validator.is_valid(body))
+        errors = sorted(validator.iter_errors(body), key=lambda e: e.path)
+        self.assertThat(errors[0].context[1].message,
+                        Equals("'-44.0' does not match '^[0-9]+$'"))
+        self.assertThat(errors[0].path.pop(), Equals('size'))
+
+    def test_validate_resize_volume_invalid_characters(self):
         body = {"resize": {"volume": {"size": 'x'}}}
         schema = self.controller.get_schema('action', body)
         validator = jsonschema.Draft4Validator(schema)
@@ -168,7 +190,7 @@ class TestInstanceController(TestCase):
         self.assertThat(errors[0].context[0].message,
                         Equals("'x' is not of type 'integer'"))
         self.assertThat(errors[0].context[1].message,
-                        Equals("'x' does not match '[0-9]+'"))
+                        Equals("'x' does not match '^[0-9]+$'"))
         self.assertThat(errors[0].path.pop(), Equals('size'))
 
     def test_validate_resize_instance(self):
@@ -183,6 +205,12 @@ class TestInstanceController(TestCase):
         validator = jsonschema.Draft4Validator(schema)
         self.assertTrue(validator.is_valid(body))
 
+    def test_validate_resize_instance_string(self):
+        body = {"resize": {"flavorRef": 'foo'}}
+        schema = self.controller.get_schema('action', body)
+        validator = jsonschema.Draft4Validator(schema)
+        self.assertTrue(validator.is_valid(body))
+
     def test_validate_resize_instance_empty_url(self):
         body = {"resize": {"flavorRef": ""}}
         schema = self.controller.get_schema('action', body)
@@ -191,16 +219,13 @@ class TestInstanceController(TestCase):
         errors = sorted(validator.iter_errors(body), key=lambda e: e.path)
         self.verify_errors(errors[0].context,
                            ["'' is too short",
-                            "'' does not match 'http[s]?://(?:[a-zA-Z]"
-                            "|[0-9]|[$-_@.&+]|[!*\\\\(\\\\),]"
-                            "|(?:%[0-9a-fA-F][0-9a-fA-F]))+'",
-                            "'' does not match '[0-9]+'",
+                            "'' does not match '^.*[0-9a-zA-Z]+.*$'",
                             "'' is not of type 'integer'"],
                            ["flavorRef", "flavorRef", "flavorRef",
                             "flavorRef"],
                            errors[0].path.pop())
 
-    @skip("This damn URI validator allows just about any garbage you give it")
+    @skip("This URI validator allows just about anything you give it")
     def test_validate_resize_instance_invalid_url(self):
         body = {"resize": {"flavorRef": "xyz-re1f2-daze329d-f23901"}}
         schema = self.controller.get_schema('action', body)
@@ -209,3 +234,79 @@ class TestInstanceController(TestCase):
         self.assertFalse(validator.is_valid(body))
         errors = sorted(validator.iter_errors(body), key=lambda e: e.path)
         self.verify_errors(errors, ["'' is too short"], ["flavorRef"])
+
+    def _setup_modify_instance_mocks(self):
+        instance = Mock()
+        instance.detach_replica = Mock()
+        instance.assign_configuration = Mock()
+        instance.unassign_configuration = Mock()
+        instance.update_db = Mock()
+        return instance
+
+    def test_modify_instance_with_empty_args(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+
+        self.controller._modify_instance(instance, **args)
+
+        self.assertEqual(instance.detach_replica.call_count, 0)
+        self.assertEqual(instance.unassign_configuration.call_count, 0)
+        self.assertEqual(instance.assign_configuration.call_count, 0)
+        self.assertEqual(instance.update_db.call_count, 0)
+
+    def test_modify_instance_with_nonempty_args_calls_update_db(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+        args['any'] = 'anything'
+
+        self.controller._modify_instance(instance, **args)
+
+        instance.update_db.assert_called_once_with(**args)
+
+    def test_modify_instance_with_False_detach_replica_arg(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+        args['detach_replica'] = False
+
+        self.controller._modify_instance(instance, **args)
+
+        self.assertEqual(instance.detach_replica.call_count, 0)
+
+    def test_modify_instance_with_True_detach_replica_arg(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+        args['detach_replica'] = True
+
+        self.controller._modify_instance(instance, **args)
+
+        self.assertEqual(instance.detach_replica.call_count, 1)
+
+    def test_modify_instance_with_configuration_id_arg(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+        args['configuration_id'] = 'some_id'
+
+        self.controller._modify_instance(instance, **args)
+
+        self.assertEqual(instance.assign_configuration.call_count, 1)
+
+    def test_modify_instance_with_None_configuration_id_arg(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+        args['configuration_id'] = None
+
+        self.controller._modify_instance(instance, **args)
+
+        self.assertEqual(instance.unassign_configuration.call_count, 1)
+
+    def test_modify_instance_with_all_args(self):
+        instance = self._setup_modify_instance_mocks()
+        args = {}
+        args['detach_replica'] = True
+        args['configuration_id'] = 'some_id'
+
+        self.controller._modify_instance(instance, **args)
+
+        self.assertEqual(instance.detach_replica.call_count, 1)
+        self.assertEqual(instance.assign_configuration.call_count, 1)
+        instance.update_db.assert_called_once_with(**args)
