@@ -18,21 +18,23 @@ from mock import MagicMock, patch, ANY
 from testtools import TestCase
 from testtools.matchers import Equals, Is, Not
 
-from novaclient.v1_1 import Client
-from novaclient.v1_1.flavors import FlavorManager, Flavor
-from novaclient.v1_1.servers import Server, ServerManager
+from novaclient.v2 import Client
+from novaclient.v2.flavors import FlavorManager, Flavor
+from novaclient.v2.servers import Server, ServerManager
 from oslo.config import cfg
 from trove.backup.models import Backup
 from trove.common.context import TroveContext
+from trove.common import exception
 from trove.common import instance as rd_instance
+from trove.common import remote
 from trove.datastore import models as datastore_models
+from trove.guestagent.api import API
 from trove.instance.models import DBInstance
 from trove.instance.models import InstanceServiceStatus
 from trove.instance.tasks import InstanceTasks
 import trove.extensions.mgmt.instances.models as mgmtmodels
-from trove.openstack.common.notifier import api as notifier
-from trove.common import remote
 from trove.tests.unittests.util import util
+from trove import rpc
 
 CONF = cfg.CONF
 
@@ -369,22 +371,78 @@ class TestMgmtInstanceTasks(MockMgmtInstanceTest):
         flavor = MagicMock(spec=Flavor)
         flavor.name = 'db.small'
 
+        notifier = MagicMock()
+        rpc.get_notifier = MagicMock(return_value=notifier)
+
         with patch.object(mgmtmodels, 'load_mgmt_instances',
                           return_value=[mgmt_instance]):
             with patch.object(self.flavor_mgr, 'get', return_value=flavor):
                 self.assertThat(self.context.auth_token,
                                 Is('some_secret_password'))
-                with patch.object(notifier, 'notify', return_value=None):
+                with patch.object(notifier, 'info', return_value=None):
                     # invocation
                     mgmtmodels.publish_exist_events(
                         mgmtmodels.NovaNotificationTransformer(
                             context=self.context),
                         self.context)
                     # assertion
-                    notifier.notify.assert_any_call(self.context,
-                                                    'test_host',
-                                                    'trove.instance.exists',
-                                                    'INFO',
-                                                    ANY)
+                    notifier.info.assert_any_call(self.context,
+                                                  'trove.instance.exists',
+                                                  ANY)
                     self.assertThat(self.context.auth_token, Is(None))
         self.addCleanup(self.do_cleanup, instance, service_status)
+
+
+class TestMgmtInstanceDeleted(MockMgmtInstanceTest):
+
+    def test_show_deleted_mgmt_instances(self):
+        args = {'deleted': 0, 'cluster_id': None}
+        db_infos_active = DBInstance.find_all(**args)
+        args = {'deleted': 1, 'cluster_id': None}
+        db_infos_deleted = DBInstance.find_all(**args)
+        args = {'cluster_id': None}
+        # db_infos_all = DBInstance.find_all(**args)
+
+        # TODO(SlickNik) Fix this assert to work reliably in the gate.
+        # This fails intermittenly when the unit tests run in parallel.
+        # self.assertTrue(db_infos_all.count() ==
+        #                 db_infos_active.count() +
+        #                 db_infos_deleted.count())
+
+        with patch.object(self.context, 'is_admin', return_value=True):
+            deleted_instance = db_infos_deleted.all()[0]
+            active_instance = db_infos_active.all()[0]
+
+            instance = DBInstance.find_by(context=self.context,
+                                          id=active_instance.id)
+            self.assertEqual(instance.id, active_instance.id)
+
+            self.assertRaises(
+                exception.ModelNotFoundError,
+                DBInstance.find_by,
+                context=self.context,
+                id=deleted_instance.id,
+                deleted=False)
+
+            instance = DBInstance.find_by(context=self.context,
+                                          id=deleted_instance.id,
+                                          deleted=True)
+            self.assertEqual(instance.id, deleted_instance.id)
+
+
+class TestMgmtInstancePing(MockMgmtInstanceTest):
+
+    def test_rpc_ping(self):
+        status = rd_instance.ServiceStatuses.RUNNING.api_status
+        instance, service_status = self.build_db_instance(
+            status, task_status=InstanceTasks.NONE)
+        mgmt_instance = mgmtmodels.MgmtInstance(instance,
+                                                instance,
+                                                None,
+                                                service_status)
+
+        with patch.object(API, 'rpc_ping', return_value=True):
+            with patch.object(API, 'get_client'):
+                self.assertTrue(mgmt_instance.rpc_ping())
+
+        self.addCleanup(self.do_cleanup, instance, service_status)
